package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.38.0 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.38.0) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@(!`0````````````,`\P`!````?",```````!``````````$"D````
M````!0```$``.``*`$``&P`:``8````$````0`````````!``````````$``
M````````,`(````````P`@````````@``````````P````0```!P`@``````
M`'`"````````<`(````````A`````````"$``````````0`````````#``!P
M!````.ZB`````````````````````````````%,````````````````````!
M``````````$````%````````````````````````````````````J)@`````
M``"HF``````````0`````````0````8```"XG0```````+BM````````N*T`
M``````#@!`````````@%`````````!`````````"````!@```-"=````````
MT*T```````#0K0```````#`"````````,`(````````(``````````0````$
M````E`(```````"4`@```````)0"````````1`````````!$``````````0`
M````````4.5T9`0```!8D0```````%B1````````6)$```````#L````````
M`.P`````````!`````````!1Y71D!@``````````````````````````````
M```````````````````````````0`````````%+E=&0$````N)T```````"X
MK0```````+BM````````2`(```````!(`@````````$`````````+VQI8B]L
M9"UL:6YU>"UR:7-C=C8T+6QP-C1D+G-O+C$`````!````!0````#````1TY5
M`*BT*]!#T+SR%$_RJVQ=NB9@S\1C!````!`````!````1TY5```````$````
M#P````````!A````9@``````````````4@````4```````````````8`````
M```````````````\`````````!`````C````7P`````````P````2@```$L`
M```]````6@```&,````O````+```````````````%P```$,````Q````````
M``````!,````50```#L`````````5@```&4````J````*`````<`````````
M#P`````````Z````6P```$D```!%`````````#<```!=````-@```"X````:
M``````````````!3````1@```#D```!"````%````````````````````#\`
M```F````````````````````+0```!(`````````%@```&0````<````````
M````````````&0```#@````^````30`````````T`````````$``````````
M`````%P`````````3@````````!!````7@```$<```!$````)P````T`````
M`````````````````````````````````````````````````````P``````
M````````````````````````````````````````````````````````"P``
M``````!A````3P``````````````#@```!L````$`````````!\`````````
M40``````````````"``````````@``````````````!@`````````"L`````
M`````````%D`````````$0````````!B````*0```%<``````````````$@`
M```R`````````"(`````````)````"$````=````#``````````*````5```
M```````>`````````````````````````````````````````!4`````````
M```````````8```````````````S````)0``````````````"0``````````
M````````````````````4````#4`````````$P````(`````````6```````
M````````$0```$@````$````"````""0$`$%0`3$*`(!!("&!(2"B0`""2`$
M"(B`$$&Z``*(`````$@```!+````3@```$\```!7````6````%H```!<````
M70```%X```!@````8@```&,```!E``````````````!NQ=\?SMY'+6M_FGPN
MQ9NVU&34?"'_Y`[9<5@<XD?&`;(!BV^L2^/`0OK7A\+E/RRZXY)\^J%L8)E/
MPYMK"4/69J_,9AE^"H="1=7LB0=PTW-0G]@S8MOM/L_2;!6,)<P,.I<+_V'R
M87^IG)O@IP(*:QJ>4*/@^TD`````````````````````````````````````
M``````,`#0#P(0``````````````````[@(``!$`````````````````````
M````K`(``!(`````````````````````````?0$``!(`````````````````
M````````A0```!(`````````````````````````$P(``!(`````````````
M````````````DP(``!(`````````````````````````R0$``!(`````````
M````````````````K@```!(`````````````````````````C`(``!(`````
M````````````````````I````!(`````````````````````````3P(``!(`
M````````````````````````W0$``!(`````````````````````````?0``
M`!$`````````````````````````E0```!(`````````````````````````
ML`$``!(`````````````````````````W@(``!(`````````````````````
M`````P(``!(`````````````````````````(0$``!(`````````````````
M````````H0$``!(`````````````````````````TP```!(`````````````
M````````````T`$``!(`````````````````````````PP```!(`````````
M````````````````6````!(``````````````````````````0```"``````
M````````````````````&`$``!(`````````````````````````Q`(``!(`
M````````````````````````'0```"``````````````````````````C@``
M`!(`````````````````````````R@```!(`````````````````````````
MM@(``!(`````````````````````````DP$``!(`````````````````````
M````>P```!$`````````````````````````V0```!8`````````````````
M````````6P$``!(`````````````````````````[````!(`````````````
M````````````A`$``!(`````````````````````````10$``!(`````````
M````````````````8@(``!(`````````````````````````P@$``!(`````
M````````````````````!P$``!(`````````````````````````SP(``!(`
M````````````````````````M0$``!(`````````````````````````-@$`
M`!(`````````````````````````L0(``!(`````````````````````````
M;P$``!(`````````````````````````UP$``!(`````````````````````
M````G@(``!(`````````````````````````=@$``!(`````````````````
M````````+P$``!(`````````````````````````F@$``!$`````````````
M````````````-`(``!(`````````````````````````BP$``!(`````````
M````````````````C0```!(`````````````````````````20```"(`````
M````````````````````'P(``!(`````````````````````````4P$``!(`
M````````````````````````O0$``!(`````````````````````````YP(`
M`!(`````````````````````````@`(``!(`````````````````````````
M[@$``!(`````````````````````````L0,``!(`````````````````````
M````<P(``!$`````````````````````````M0```!(`````````````````
M````````_````!(`````````````````````````0`(``!(`````````````
M````````````-P```!(`````````````````````````G````!(`````````
M````````````````8@$``!(`````````````````````````:@```!(`````
M````````````````````_`$``!(`````````````````````````N@,``!(`
M#0!&3````````*@`````````3`0``!(`#0"010````````8%````````1```
M`!(`#0#P(0```````(H!````````,0,``!(`#0"4/`````````(`````````
M3P,``!(`#0"62@```````+`!````````<@0``!(`#0"6/````````-8!````
M````,@0``!``%P"8L@``````````````````0@,``!(`#0!L/@```````"(`
M````````90,``!(`#0#H0@```````$X`````````T@,``!$`#@#@3P``````
M``0`````````#P0``!(`#0!"30```````-P`````````*@0``!(`#0"F.P``
M`````"@`````````1P0``!``%P#`L@``````````````````8`0``!(`#0"V
M1````````-H`````````B00``!(`#0`V0P```````$0`````````X0,``!``
M%0``L```````````````````B0,``!(`#0"./@````````(!````````_0,`
M`!``\?\`N```````````````````600``!``%@"8L@``````````````````
M?P0``!$`%0!(L`````````@`````````&@0``!``%@"8L@``````````````
M````YP,``!(`#0!\(P```````"(`````````[@,``!``%0``L```````````
M````````/@0``!(`#0#N3````````%0`````````XP,``"``%0``L```````
M````````````Q@,``!``%P#`L@``````````````````GP,``!(`#0">1```
M`````!@`````````<P,``!(`#0#..P```````,8`````````E0,``!(`#0`>
M3@```````+(!````````D00``!(`#0"0/P```````%@#`````````%])5$U?
M9&5R96=I<W1E<E1-0VQO;F5486)L90!?251-7W)E9VES=&5R5$U#;&]N951A
M8FQE`%]?;&EB8U]S=&%R=%]M86EN`%]?8WAA7V9I;F%L:7IE`%]?<F5G:7-T
M97)?871F;W)K`%]?<W1A8VM?8VAK7V9A:6P`7U]E;G9I<F]N`'-T<FYC;7``
M;'-T870V-`!A8V-E<W,`;W!E;F1I<@!R96%D9&ER-C0`<W1R;&5N`%]?<W!R
M:6YT9E]C:&L`=6YL:6YK`&-L;W-E9&ER`')M9&ER`%!,7V-U<G)E;G1?8V]N
M=&5X=`!B;V]T7T1Y;F%,;V%D97(`4&5R;%]N97=84P!097)L7VYE=UA37V9L
M86=S`')E861L:6YK`%!E<FQ?<W9?<V5T<'8`;65M8VAR`%!E<FQ?<W9?<V5T
M<'9N`%]?;65M;6]V95]C:&L`<F5A;&QO8P!G971P:60`7U]M96UC<'E?8VAK
M`'-T<F-H<@!S=')D=7``<W1R=&]K`'-T<F-M<`!S=')R8VAR`&UE;6-P>0!S
M=&1E<G(`7U]V9G!R:6YT9E]C:&L`97AI=`!L<V5E:S8T`')E860`;65M8VUP
M`&=E='5I9`!S=')S='(`;6MD:7(`7U]E<G)N;U]L;V-A=&EO;@!?7V9P<FEN
M=&9?8VAK`&]P96XV-`!097)L7V=V7V9E=&-H<'8`4&5R;%]G971?<W8`4&5R
M;%]C<F]A:U]N;V-O;G1E>'0`4&5R;%]M9U]S970`4&5R;%]S>7-?:6YI=#,`
M4&5R;%]A=&9O<FM?=6YL;V-K`%!E<FQ?871F;W)K7VQO8VL`4$Q?9&]?=6YD
M=6UP`%!E<FQ?<V%F97-Y<VUA;&QO8P!P97)L7W!A<G-E`'!E<FQ?9&5S=')U
M8W0`<&5R;%]F<F5E`%!E<FQ?<WES7W1E<FT`<&5R;%]A;&QO8P!P97)L7V-O
M;G-T<G5C=`!P97)L7W)U;@!M96US970`7U]S=&%C:U]C:&M?9W5A<F0`;&EB
M<&5R;"YS;P!L:6)C+G-O+C8`;&0M;&EN=7@M<FES8W8V-"UL<#8T9"YS;RXQ
M`'!A<E]C=7)R96YT7V5X96,`<&%R7V)A<V5N86UE`%A37TEN=&5R;F%L<U]0
M05)?0D]/5`!P87)?96YV7V-L96%N`'!A<E]C=7)R96YT7V5X96-?<')O8P!P
M87)?9&ER;F%M90!S:&%?9FEN86P`9V5T7W5S97)N86UE7V9R;VU?9V5T<'=U
M:60`<&%R7V-L96%N=7``7U]"4U-?14Y$7U\`7TE/7W-T9&EN7W5S960`7U]D
M871A7W-T87)T`%]?1$%405]"14=)3E]?`%]?9VQO8F%L7W!O:6YT97(D`'-H
M85]U<&1A=&4`7U]31$%405]"14=)3E]?`'AS7VEN:70`7U]B<W-?<W1A<G0`
M<VAA7VEN:70`7V5N9`!P87)?;6MT;7!D:7(`7V5D871A`'!A<E]S971U<%]L
M:6)P871H`'!A<E]F:6YD<')O9P!M>5]P87)?<&P`<&%R7V1I90!P87)?:6YI
M=%]E;G8`1TQ)0D-?,BXS-`!'3$E"0U\R+C,S`$=,24)#7S(N,C<`+W5S<B]L
M:6(O<&5R;#4O-2XS."XP+W)I<V-V-C0M;&EN=7@M=&AR96%D+6UU;'1I+T-/
M4D4````````"``$``P`#``$``0`#``,``P`#``$``P`#``,``P`!``$``0`#
M``,``P`#``,``0`#``$``0`$``,``0`#``,``0`#``$``P`#``$``P`!``$`
M`P`!``,``P`#``$``P`#``,``0`#``0``P`!``,``P`#``$``P`#``$``P`!
M``$`!0`#``,``P`#``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$`
M`0`!``$``0`!``$``0`!``$``0`!``$``0`!``````````$``P`+`P``$```
M`$````"TD98&```%`)X$```0````LY&6!@``!`"I!```$````(>1E@8```,`
MM`0````````!``$`%0,``!``````````AY&6!@```@"T!````````+BM````
M`````P````````">(P```````,"M`````````P`````````R)````````,BM
M`````````P````````#X(P````````"P`````````P``````````L```````
M`!BP`````````P````````!`40```````""P`````````P`````````8D0``
M`````"BP`````````P`````````@D0```````#"P`````````P`````````H
MD0```````#BP`````````P`````````PD0```````$BP`````````P``````
M``"H4P```````)"R`````````P````````#P(0```````#BR`````````@``
M``(``````````````$"R`````````@````P``````````````$BR````````
M`@````X``````````````%"R`````````@```!D``````````````%BR````
M`````@```!P``````````````&"R````````"P```"(``````````````&BR
M`````````@```"0``````````````'"R`````````@```"<`````````````
M`'BR`````````@```#,``````````````("R`````````@```#<`````````
M`````(BR`````````@```#\``````````````&"P````````!0````,`````
M`````````&BP````````!0````0``````````````'"P````````!0````4`
M`````````````'BP````````!0````8``````````````("P````````!0``
M``<``````````````(BP````````!0````@``````````````)"P````````
M!0````D``````````````)BP````````!0````H``````````````*"P````
M````!0````L``````````````*BP````````!0````T``````````````+"P
M````````!0````\``````````````+BP````````!0```!``````````````
M`,"P````````!0```!$``````````````,BP````````!0```!(`````````
M`````-"P````````!0```!,``````````````-BP````````!0```!0`````
M`````````."P````````!0```!4``````````````.BP````````!0```!8`
M`````````````/"P````````!0```!<``````````````/BP````````!0``
M`!@```````````````"Q````````!0```!H```````````````BQ````````
M!0```!L``````````````!"Q````````!0```!T``````````````!BQ````
M````!0```!X``````````````""Q````````!0```!\``````````````"BQ
M````````!0```"```````````````#"Q````````!0```",`````````````
M`#BQ````````!0```"4``````````````$"Q````````!0```"8`````````
M`````$BQ````````!0```"@``````````````%"Q````````!0```"D`````
M`````````%BQ````````!0```"H``````````````&"Q````````!0```"L`
M`````````````&BQ````````!0```"P``````````````'"Q````````!0``
M`"T``````````````'BQ````````!0```"X``````````````("Q````````
M!0```"\``````````````(BQ````````!0```#```````````````)"Q````
M````!0```#$``````````````)BQ````````!0```#(``````````````*"Q
M````````!0```#0``````````````*BQ````````!0```#4`````````````
M`+"Q````````!0```#8``````````````+BQ````````!0```#@`````````
M`````,"Q````````!0```#D``````````````,BQ````````!0```#H`````
M`````````-"Q````````!0```#L``````````````-BQ````````!0```#P`
M`````````````."Q````````!0```#T``````````````.BQ````````!0``
M`#X``````````````/"Q````````!0```$```````````````/BQ````````
M!0```$$```````````````"R````````!0```$(```````````````BR````
M````!0```$,``````````````!"R````````!0```$0``````````````!BR
M````````!0```$4``````````````""R````````!0```$8`````````````
M`"BR````````!0```$<`````````````````````````EY,``#,#PT$#O@,B
M$P-#_9."`R(34Q,`@[*"`&<`#@`7G@```SX.(6<##@`3````%YX```,^CB!G
M`PX`$P```!>>```#/@X@9P,.`!,````7G@```SZ.'V<##@`3````%YX```,^
M#A]G`PX`$P```!>>```#/HX>9P,.`!,````7G@```SX.'F<##@`3````%YX`
M``,^CAUG`PX`$P```!>>```#/@X=9P,.`!,````7G@```SZ.'&<##@`3````
M%YX```,^#AQG`PX`$P```!>>```#/HX;9P,.`!,````7G@```SX.&V<##@`3
M````%YX```,^CAIG`PX`$P```!>>```#/@X:9P,.`!,````7G@```SZ.&6<#
M#@`3````%YX```,^#AEG`PX`$P```!>>```#/HX89P,.`!,````7G@```SX.
M&&<##@`3````%YX```,^CA=G`PX`$P```!>>```#/@X79P,.`!,````7G@``
M`SZ.%F<##@`3````%YX```,^#A9G`PX`$P```!>>```#/HX59P,.`!,````7
MG@```SX.%6<##@`3````%YX```,^CA1G`PX`$P```!>>```#/@X49P,.`!,`
M```7G@```SZ.$V<##@`3````%YX```,^#A-G`PX`$P```!>>```#/HX29P,.
M`!,````7G@```SX.$F<##@`3````%YX```,^CA%G`PX`$P```!>>```#/@X1
M9P,.`!,````7G@```SZ.$&<##@`3````%YX```,^#A!G`PX`$P```!>>```#
M/HX/9P,.`!,````7G@```SX.#V<##@`3````%YX```,^C@YG`PX`$P```!>>
M```#/@X.9P,.`!,````7G@```SZ.#6<##@`3````%YX```,^#@UG`PX`$P``
M`!>>```#/HX,9P,.`!,````7G@```SX.#&<##@`3````%YX```,^C@MG`PX`
M$P```!>>```#/@X+9P,.`!,````7G@```SZ."F<##@`3````%YX```,^#@IG
M`PX`$P```!>>```#/HX)9P,.`!,````7G@```SX."6<##@`3````%YX```,^
MC@AG`PX`$P```!>>```#/@X(9P,.`!,````7G@```SZ.!V<##@`3````%YX`
M``,^#@=G`PX`$P```!>>```#/HX&9P,.`!,````7G@```SX.!F<##@`3````
M%YX```,^C@5G`PX`$P```!>>```#/@X%9P,.`!,````7G@```SZ.!&<##@`3
M````'7&&[*;DJH>BZ,K@3OR7E```@[2D`R[H,N0,"#``:`@^SIQ@/O2!1^_P
MG_<7E@```S9&`K*%%Y4```,UI03O(#!:EY<``(.W9P6#QP<`\<^7EP``@[<'
M`A>4```3!(0%DI>88W))@T>G2QL%20`.!9/G-P`C#?=*[_"?[<)E\D<(Y)AA
M#2FJAACA%S<``!,'YQ$8Y1>7```#-T?<&.D7-P``$P<G$1CM!4=C6?<,&X@W
M`$*&H0411XAADQ<W`+:7!2>(XZ$%XQD'_YL'!@".!PALMI<!1TJ&EQ4``).%
M15XCL`<`[_#?NSW%"&R3"4$"[_`?W"J)SH47-0``$P6%WN\0X#HIS0AL[_"?
MM>_P7\TB=YQ@N8\!1[WGYF!&9*9DXGE*A09I)6&"@._P?\@7E```$P0D^`CL
M(<7O\'_1EY<``(.W)_.%9C.'1P`88S:7(P<'FC&W"&SO\)^\>;<(:`'%[R!0
M#T6WSH47-0``$P7ES^\0P#,(Z%G5Y;>11X&_!47O\/^X[_"_Y0``[P`@`JJ'
M%Y4```,UY?""93``$W$!_X%&`4<*B._PG^`"D)>1``"3@2%&@H```!>5```3
M!67*EY<``).'Y\ECB*<`EY<``(.W)^F1PX*'@H`7E0``$P5%R)>5``"3A<7'
MB8V3US5`_9&^E86%F<67EP``@[?GYI'#@H>"@$$1(N`7E```$P3$Z8-'!``&
MY(7CEY<``(.W1^>1QQ>5```#-:6^@I?O\+_XA4<C`/0`HF`"9$$!@H!IOQ,!
M`=0C.($J(SP1*B,TD2HC,"$K(SPQ*2,X02D7E````S2$WC0`P6Y]7QQ@(S3Q
M*(%'DPB%`Y,"A0<VB!-?#P*W#_\`DXX.\`.V"`!!"*$(DU4&`A,7A@&3$X8`
MDU>&`A->A@"35(8#$Y.%`3-WYP&S\_,!L_?7`3-G=P`S?MX!Q8\S<^,!H@4S
M9\<!&U:&`;/G9P"S]?4!48_-CR,XZ/XC//C^XY(2^_U5QG]F?PIGXFX"?B)S
MPGAB>(9CDX0&((&1$:"R@[!BG&*Z@J$&L8^SQ_<!L\?7`1.7%P#]@UV/;8^X
M_OJ/\HX6CQJ.1H/"B!Z(XYF6_(,^!0"B;P,X!0$#,X4`@SB%`0,^!0(WAX):
M$P>7F9/7O@$3EEX`78ZZGQ-?(P"3%^,!;8[RG[-&&`&SY^<!L_9F`'Z6PF\S
M_[<`L\86`3:6LT;H`6V.L_;6`;J?DQ)6`)-4M@'&G[/&!@'^EK/OD@`3V2X`
MDY/N`?Z6XF^SXR,!L\=W`/&/NI_MCK/'YP'"GY.45@`3V;8!DQ+F`?Z7"8*"
M?[/BP@`SYB0!LI<SQE,`NI^S\[,`=8[MCWZ?,T9V`).45P`3V;<!DY_F`7J6
MB8(B?[/OWP"SYB0!-I:SQO(!;8ZS\K(`_8XZGQZ?DQ16`!-9M@&SQE8`DY/G
M`8F#L^/S`/J6L^<D`;Z6,_^V`,)VL\=_`/&/L_^_`+J6EI:3%%\`$UF_`;/'
M]P&VE[/F)`&VEY,2Y@$)@K/BP@`S]K<`XG>SQE,`L_;F`;/SLP"ZE_Z7DQ16
M`!-9M@&SQG8`OI:SYR0!OI:3'^\!$U\O`+/O[P$S_[8`AF:SQ_(!\8^S\K(`
MNI:>EI,47P`36;\!L\=7`+:7L^8D`;:7DQ/F`0F"L^/#`#/VMP"F9[/&?P"S
M]N8!L_^_`+J7EI>3%%8`$UFV`;/&]@&^EK/G)`&^EI,2[P$37R\`L^+B`3/_
MM@#&9K/'4P#QC[/SLP"ZEOZ6DQ1?`!-9OP&SQW<`MI>SYB0!MI>3'^8!"8*S
M[\\`,_:W`.9GL\;R`;/VY@&S\K(`NI>>EY,45@`36;8!L\96`+Z6L^<D`;Z6
MDQ/O`1-?+P"SX^,!,_^V`(9VL\=_`/&/L_^_`+J6EI:3%%\`$UF_`;/']P&V
ME[/F)`&VEY,2Y@$)@K/BP@`S]K<`IG>SQE,`L_;F`;/SLP"ZE_Z7DQ16`!-9
MM@&SQG8`OI:SYR0!OI:3'^\!$U\O`+/O[P$S_[8`QG:SQ_(!\8^S\K(`NI:>
MEI,47P`36;\!L\=7`+:7L^8D`;:7DQ/F`0F"L^/#`#/VMP#F=[/&?P"S]N8!
ML_^_`+J7EI>3%%8`$UFV`;/&]@&^EK/G)`&^EI,2[P$37R\`L^+B`3/_M@"*
M9K/'4P#QC[/SLP"ZEOZ6DQ1?`!-9OP&SQW<`MI>SYB0!MI>3'^8!"8*S[\\`
M,_:W`*IGL\;R`;/VY@&S\K(`NI>>EY-4M@&3$U8`L\96`!,9[P&^EA-?+P"S
MYY,`RF,S;^D!OI:SQ^\![8ZS_[\`NI/QCYZ2D]2V`;/']P&3DU8`L^.3`):7
MZF23$N8!"8*SXL(`GI?MCS-&7P"ZE#-_OP`3V;<!=8Z3DU<`II\S1N8!L^,C
M`;/SLP!^EI.?Y@&)@AZ6L^_?``IYLW2V`+/&\@']CK/RL@"3DU0`D]FT`3J9
M,\=6`+/F,P&3D^<!B8.SX_,`2I^SQW\`[8YZE[&/*G8S#]<`-_?9;A,'%[JS
M>;\`$]FY`3J6DY99`!:6[8^SYB8!LI?MCKZ6DY+D`<IWB8"SXI(`,_FV`#/&
M4P"S_[\`DU2Y`;J7,T_F`1,660`S?[\`_I=%COJ7;8X^EI.?Z0'J=Y/9*0"S
M[S\!LW2V`#//\@&S\[,`D]FT`;J7,T_?`).65``S?[\`GI>SYC8!^I?MCKZ6
M$Q_I`8YG$UDI`#-O+P&S\[8`,\GO`;/YL@"ZE[-"R0`3V;,!$Y93`+/RL@#.
MES-F)@&6EVV./I:3DN0!KF>)@+/BD@`S25\`LW2V`+/YOP"ZE[-/V0`3V;0!
MDY94`+/_OP#.E[/F)@'^E^V.OI:3G^,!SF>3TR,`L^]_`#/)\@&S\[8`LWF_
M`+J7,T_)`!/9LP$3EE,`,W^_`,Z7,V8F`?J7;8X^EA.?Y`'N9XF`,V^?`#/)
M[P&S=+8`L_FR`+J7LT+9`!/9M`&3EE0`L_*R`,Z7L^8F`9:7[8Z^EI.2XP&.
M=Y/3(P"SXG(`,TE?`+/SM@"S^;\`NI>S3\D`$]FS`1.64P"S_[\`SI<S9B8!
M_I=MCCZ6DY_D`:YWB8"S[Y\`,\GR`;-TM@"S>;\`NI<S3]D`$]FT`9.65``S
M?[\`SI>SYB8!^I?MCKZ6$Y_C`<YWD],C`#-O?P`SR>\!L_.V`+/YL@"ZE[-"
MR0`3V;,!$Y93`+/RL@#.ES-F)@&6EVV./I:3DN0![G>)@+/BD@`S25\`LW2V
M`+/YOP"ZE[-/V0`3V;0!DY94`+/_OP#.E[/F)@'^E^V.OI:3G^,!DF>3TR,`
ML^]_`#/)\@&S\[8`LWF_`+J7,T_)`!/9LP$3EE,`,W^_`,Z7,V8F`?J7;8X^
MEA.?Y`&R9XF`,V^?`#/)[P&S=+8`L_FR`+J7LT+9`!/9M`&3EE0`L_*R`,Z7
ML^8F`9:7[8Z^EI.2XP'29Y/3(P"SXG(`,TE?`+/SM@"S^;\`NI>S3\D`$]FS
M`1.64P"S_[\`SI<S9B8!_I=MCCZ6DY_D`?)GB8"S[Y\`,\GR`;-TM@"S>;\`
MNI<S3]D`$]FT`9.65``S?[\`SI>SYB8!^I?MCKZ6$Y_C`9)WD],C`#-O?P`S
MR>\!L_.V`+/YL@"ZE[-"R0`3V;,!$Y93`+/RL@#.ES-F)@&6EVV./I:3DN0!
MLG>)@+/BD@`S25\`LW2V`+/YOP"ZE[-/V0`3V;0!DY94`+/_OP#.E[/F)@'^
ME^V.OI:3G^,!TG>3TR,`L^]_`#/YM@"SP_(!LWF_`+J7,\_#`)-3N0$3%ED`
M,W^_`,Z7,V9V`&V.^I<SC\<`DY/D`?)WB8"SXY,`,\9_`+-TOP"S\K(`NI>Q
MCNV.D]FT`9:7DY)4`+:7L^8R`;:7$Q;I`99F$UDI`#-F)@$SR<,`L_*W`+/_
MOP"S1^D!NI:3V;(!_I83F5(`L_^W`#-I.0'^ELJ6$Y_D`8F`,V^?`#?WQB.S
M=+8`_5?UC;9F@9,*!Q,'Q\VS?_\`,V;F`3/Y]`&ZEC-V5@"S\_,`MI.3V;4!
M,V8F`1.950`>EK-C.0$>EK-S]@"3EN(!5F:3TB(`L^96`+/R]@`S;]\`,_E?
M`#J6,W^_`+*4D]FS`3-O+P$3F5,`)I^S9#D!$Y;E`2:?B8'V9$V.LW7V`-&.
M,W__`#/YL@"S]G8`NI3^E)-9OP&SYB8!$QE?`*:6LV0Y`1.:XP&3WR,`II:6
M=+-O^@&S\_\`,V;V`?V.,_EU`+J4,W;F`::2,V8F`9.45@`3V;8!L^0D`1:6
MDQGO`2:6$U\O`+9T,^_I`;-R_P"S[^\!?8XS^5,`L__?`+J4L^\O`:Z4$QE6
M`)-9M@&3E>8!B8+5C;.&GP"S;SD!_I;6?[/T]0`S;[\`_8XS^9(`NI\S?\\`
M,V\O`?Z3$YE6`)/9M@&3'^8!"8*S[\\`,P9_`#-O.0%ZEG9_L_/_`+/E]0%]
MCC/Y=``ZG_6-L^4E`?J2$QE6`)-9M@$3G^8!B8(S;]\`LX95`+-E.0&NEIIE
MLW+_`+/O[P']CC/Y4P"ZE;/_SP"S[R\!KI03F58`D]FV`9,5Y@$)@M&-,X:?
M`+-O.0%^EKIOL_3U`#-OOP!]CC/YD@"ZGS-_WP`S;R\!_I,3&58`DUFV`9.?
MY@&)@K/OWP"S!G\`,V\Y`?J66F^S\_\`L^7U`?V.,_ET`#J?\8VSY24!^I(3
MF58`D]FV`1,?Y@$)@C-OSP`SAE4`LV4Y`2Z6^F6S<O\`L^_O`7V.,_E3`+J5
ML__?`+/O+P&NE!,95@"36;8!DY7F`8F"U8VSAI\`LV\Y`?Z6FG^S]/4`,V^_
M`/V.,_F2`+J?,W_/`#-O+P'^DQ.95@"3V;8!DQ_F`0F"L^_/`#,&?P`S;SD!
M>I8Z?[/S_P"SY?4!?8XS^70`.I_UC;/E)0'ZDA,95@"36;8!$Y_F`8F",V_?
M`+.&50"S93D!KI;:=;-R_P"S[^\!_8XS^5,`NI6S_\\`L^\O`:Z4$YE6`)/9
MM@&3%>8!"8+1C3.&GP"S9#D!)I;Z=+/_]0`S;[\`?8XS^?(!,W_?`+J4,V\O
M`9Z4$QE6`)-9M@&3D^8!B8*SX],`LP:?`+-D.0$>:3/_\P"SY74`II;QC;/T
M[P$ZF?V.%IG%C9.95@`3VK8!DU(F`),4Y@'*E3YIL^14`#/F20&S\O0`LI4S
MYI,`=8ZS\_4`.IFS=5\`?IF3F5,`$]JS`4V.D]\F`).5Y@%*EK/F20&SY?4!
M-I:SYK0`LW3V`%YFL__U`#/Y\@&S]G8`.I9ZEK/F)@$3GU0`$]FT`3-O+P&R
MEGYI$Y;C`9/3(P`S9G8`LW/V`/J6T8W]CC/Z?P#EC3J9$Y]6`)/9M@$6F;/E
M10&S8C\!RI43WR0`$YGD`;-DZ0$>?[/R\@"6E46.L_+T`#/Y]0`S^E,`=8XZ
MGY-9N0$3%UD`?I\S9D8!LV\W`7J6DYGF`1/?)@`S[^D!L\;D`;/__P"MCC>W
MF#*^=;*?"@<3!V<=L_G_`)/4N0&ZE1.660">E?V.18Z3$^D!$UDI`+/C(P%]
MCJZ6LX7&`#-&?P`S1O8!WG^S]/4`$]FT`;J?DY94`):??8ZSYB8!_8Y^EC:6
MDY_I`?YVD]DI`+/O/P$S>?8`L\+S`;-Y_P"ZEC//L@"34KD!DQ59`#-__P#.
MEK/E50#ZEOV-MI43G^0!@S8!((F`,V^?`+/"[P&S]/4`L_/S`)/9M`&ZEK/"
MP@`3EE0`L_+R`)Z6,V8V`9:6?8XVEI,2Z0&#-H$@$UDI`+/B(@&S<_8`,TE?
M`+/Y_P"ZEK-/N0`3V;,!DY53`+/__P#.EK/E)0'^EOV-MI63G^0!@S8!(8F`
ML^^?`#/)\@&S]/4`LWG_`+J6,T_)`!/9M`$3EE0`,W__`,Z6,V8F`?J6?8XV
MEA.?XP&#-H$AD],C`#-O?P`SR>\!LW/V`+/Y\@"ZEK-"N0`3V;,!DY53`+/R
M\@#.EK/E)0&6EOV-MI63DN0!@S8!(HF`L^*2`#-)7P"S]/4`L_G_`+J6LT_)
M`!/9M`$3EE0`L___`,Z6,V8F`?Z6?8XVEI.?XP&#-H$BD],C`+/O?P`SR?(!
MLW/V`+-Y_P"ZEC-/N0`3V;,!DY53`#-__P#.EK/E)0'ZEOV-MI43G^0!@S8!
M(XF`,V^?`#/)[P&S]/4`L_GR`+J6LT+)`!/9M`$3EE0`L_+R`,Z6,V8F`9:6
M?8XVEI.2XP&#-H$CD],C`+/B<@`S25\`LW/V`+/Y_P"ZEK-/N0`3V;,!DY53
M`+/__P#.EK/E)0'^EOV-MI63G^0!@S8!)(F`L^^?`#/)\@&S]/4`LWG_`+J6
M,T_)`!/9M`$3EE0`,W__`,Z6,V8F`?J6?8XVEA.?XP&#-H$DD],C`#-O?P`S
MR>\!LW/V`+/Y\@"ZEK-"N0`3V;,!DY53`+/R\@#.EK/E)0&6EOV-MI63DN0!
M@S8!)8F`L^*2`#-)7P"S]/4`L_G_`+J6LT_)`!/9M`$3EE0`L___`,Z6,V8F
M`?Z6?8XVEI.?XP&#-H$ED],C`+/O?P`SR?(!LW/V`+-Y_P"ZEC-/N0`3V;,!
MDY53`#-__P#.EK/E)0'ZEOV-MI43G^0!@S8!)HF`,V^?`#/Y]0"SQ.\!L_GR
M`+J6L\+$`)-4N0$3%ED`L_+R`,Z618Z6EGV.-I:3E.,!@S:!)I/3(P"SY'0`
MLT*?`+-S]@"S^?\`NI:SS[(`D]*S`9.54P"S__\`SI:SY54`_8W^EK./M@"3
M$ND!@S8!)Q-9*0"SXB(!L\54`#/Y_P`S?_\`DUFY`;J6L8T3%ED`_8WZEC-F
M-@%]CJZ6LX7&`!.?XP$#-H$GD],C`#-O?P"SQN(!L_/U`/V,.I:SQO8!_8XF
MEI/9LP&3E%,`-I:SYC0!-I:#-@$HDQ_I`1-9*0"S[R\!NI:S1/\!,W?V`/:6
ML_+R`#/&M`!]CI,55P"37K<!EI:REC/FU0&3E>,!D],C`+*6L^5U`/V..I,S
M!L\!,X<%`;.%'P%]CQ3A_8VS=O,`\8\8Z1SQ%.4,[0,W@2@<8+F/`4>%XX,P
M@2L#-`$K@S2!*@,Y`2J#.8$I`SH!*1,!`2R"@._@?[,Y<0;\(OA9Q5K@EX<`
M`(.W![H#NP<`8P$+"$KP3NQ2Z(-'!0"JB2Z**HD3!]`#I<MCAN<`@T<9``4)
M_?L["3E!`S0+`#G,)O16Y-J$DPK0`TJ&SH4BA>_@S_>S!R0!">6#QP<`8X!7
M`X!DH01U\*)T`GGB:4)JHFH":^)P(H5"="%A@H"SA&1!C80%"2,@F@!*E/&_
M`435MP)K`43YOP%)1;<">>)I0FH":\&_<7$B\2;M!O67A```@[1DKBP`G&`^
MY8%'*H3OX-^8#>'B1[UF$6?UCV.%YP`I9V.:YP")12*%[^`/]Q,U%0`1H`%%
M*F><8+F/`4>1YZIP"G3J9$UA@H#OX!^C,7%.[0;]EXD``(.YZ:B#MPD`/N6!
M1QG%(OF#1P4`*H2)[TIT*F>#MPD`N8\!1V.7!PSJ<.II*6&"@";U2O'OX/^<
MJH19R2:%[^!/[DG!@T8U`1,)-0&;AB;]@>:#1AD`_=(#1S4!&P<G_27/(H52
MZ>_@S^DJBDJ%[^!/Z3L*J@`)*E*%[^"/Z<J'(H>7%@``DX:&>U*&B44JB>_@
M/Y,L`$J%[^"O]OU78PCU`.)'O6819_6/8X#G!$J%[^`O\4J%[^#?@":%2FKO
MX$_F2?$FA>_@S_0BA>_@;^U*=*IT"GF1MP-'&0`;!R?]2?,#1RD`.=NMOTJ%
M[_"_\-&W(ODF]4KQ4NGOX)^201$BX!>$```#-`2;!N279@``DX9FB+,'1`"(
M8Q>&```#-@::EQ4``).%!7+OX)^*$I0(8`)DHF`7)P``$P?'JH%'NH87%@``
M$P9F&I<5``"3A85Q00%OX._R77%6[/UWA6K]<N$7$X<*`:+@)OQ*^$[T4O"&
MY#Z7%I&NB;,%)P`3AXH`"I<%9!>)```#.4F0*HH3!O3_%Q4``!,%96Z#-PD`
M'..!1^_@[^.;!`4`8UZ0`!.'"@$*ES,$AT";A_3_/I0#1X3_*>.=[Y>'``"#
MMZ>.3H;2A9*7B&/OX*_:A6>A!XJ7F&.#-PD`N8\!1[GGA6(6D:9@!F3B=$)Y
MHGD">N)J86&"@+Z$_7<%9^$700<^ES,$)P`FAI,%\`(BA>_@;^]%U9>'``"#
MMP>)IH8BAI*7B&/2A>_@[^=5M^_@C_Y9<:+PINS*Z-+@AO3.Y%KX7O2#QP4`
M%XD```,Y:8.JA).'-_R3MQ<`,X3U`"*%@S<)`#[D@4?OX._(*HI,`":%[_`_
MQWG)JHGOX,_'8W9%"Q)+EXL``(.[JX`."P/'!`"FAY,&T`-C#`<28P;7``/'
M%P"%!WW[A9^#N0L`$P4J`#Z5VIGOX`_%(["I`#'%`[<+`(/'!``3A10`6I<4
M8Q,&T`,C@/8`@>N]H(-'!0`%!:,`]P"MPS:'A0;CF,?^DP;0`Y,'%P`C`-<`
M`T<$`(4'!02CC^?^=?LB9X,W"0"YCP%'^>.F<`9TYF1&::9I!FI">Z)[96&"
M@(-'!`"%"04$HX_Y_O';@T<$`(4)!02CC_G^_?/1MS:'7;=6_&+P9NR7>P``
M@[O+<X.\"P"#MPP`K<OFAX%)F&?.AJ$'A2EE_XTFDYHV`)=W``"3A^=VF$,%
M[P5'5H68P^_@S[<JC#')$YLY`-:&6H;FA>_@K\LCL(L!FX<9`(X'/IPC,`P`
MXGH"?.)L3L+9O=:%9H7OX(_9(["K`"J,$<T3FSD`V;^!1^&]P4J!246W5OQB
M\&;L[^!OX^)Z`GSB;`6WEW<``(.WIVN75@``DX8F61=V```#-B9KDI>(8Y<5
M``"3A>5";^!OVUUQ)OSY<HEDAN2BX$KX3O12\!.'A`$6D0J7EWD``(.Y"66#
MMPD`'..!1^_@C[_]=\$7DX8$`KZ6,X0F``5F*H>7%P``DX>G0I<6``"3AJ9"
M!0:)12*%[^#/U/EUH163AP0"KI>SA"<`(H4%9J:%[^!/M1L$!0`!26-!!`(;
M"A0`4H7OX`^G*HD)R2*&TH:FA4J4[^`/UB,`!`")9^$'BI>88X.W"0"YCP%'
M@>^)8A:1IF!*A09DXG1">:)Y`GIA88*`[^`/U"V_A6;]=U%Q_7*3AT?W$X<&
M":+QINW*Z6+QAO7.Y=+A5OU:^5[U9NUJZ3Z7%I$NA+,%)P`3AX8("I<7?```
M`SRL5BJ)@S<,`!SC@4<7%0``$P6%-^_P?YNJA),%\`)*A>_@S[@AQ1<5```3
M!>4VRH7O\)_.2H6%9Y.'APB*EYAC@S<,`+F/`4=CE@<4A6(6D:YP#G3N9$YI
MKFD.:NIZ2GNJ>PI\ZFQ*;6UA@H`BA>_@[[:7%0``DX4E,^_@+Y$JA%W1A6?]
M>>$9$X<'"4Z7LPDG`!.'!PF3AP<)BI>%:GUZLXQ708-'!``3"HKW4I>7&P``
MDXOK+Q<;```3"^LO,PHG`,G+D<2BA2:%[^`OIC7%(H7OX*^0DP?U_Z*7*HV3
M!O`"8VCT`#&H(X`'`/T78P;T``/'!P#C"=?^(H7OX`^.*HU*A>_@CXUJE04%
MXWU5\8E%2HC>AR*'VH8%9DZ%[^#OM]*%3H7OX&^;`>F#IXSXO68A9_6/8X_G
M`I<5``"3A:4F`47OX(^$*H3C#@7L@T<$`*W[D<2#QP0`FX<G_9G'!4T7%```
M$P2D(6&_@\<4`.G7_;>%14Z%[^!/BEW]SH47%0``$P5%(>_P'[E.A>_@[Z15
MM>_@C[9!$9,%\`(BX`;D*H3OX(^F&<$3!!4`(H4"9*)@00%OX&^B>7&%9_UR
M2N@&]"+P)NP3AX<`%I$7>0```SEI.0J7@S<)`!SC@4=-P8-'!0"JA,G/[]`_
M_Q,&%0"%9RJ$8^_'"GUW81?!![J7,X<G`*:%.H7OX"^0DP?T_ZJ7DP;P`F-H
M]0`1J".`!P#]%V.&IP`#QP<`XPG7_GUUA6=A%<$'JI<SA"<`DP7P`B*%[^"/
MG`W-8V*D!GUUA6=A%<$'JI<SA2<`[^`/F(5GH0>*EYAC@S<)`+F/`4>AYX5B
M%I&B<`)TXF1":45A@H"%9Z$'BI>88X,W"0"YCP%'G>.%8A:1HG`"=.)D0FD7
M%0``$P7%#45A;^`ODR,`!0!QOP%%;;?OX$^D.7$B^";T2O!.[`;\EW0``(.T
MQ"F<8#[D@4=``!<9```3"4D.EWD``(.Y22FBA4J%[_#O[17!$D>#MPD`#@>Z
MEYAGF.-EUYAKH0>8XVW_HH5*A>_PS^ME\1<9```3"8D+EWD``(.YB26BA4J%
M[_`OZA7!$D>#MPD`#@>ZEYAGF.-EUYAKH0>8XVW_HH5*A>_P#^AE\1<9```3
M"4D(EWD``(.YR2&BA4J%[_!OYA7!$D>#MPD`#@>ZEYAGF.-EUYAKH0>8XVW_
MHH5*A>_P3^1E\1<9```3"8D%EWD``(.Y"1ZBA4J%[_"OXA7!$D>#MPD`#@>Z
MEYAGF.-EUYAKH0>8XVW_HH5*A>_PC^!E\1<9```3"4D"EWD``(.Y21JBA4J%
M[_#OWA7!$D>#MPD`#@>ZEYAGF.-EUYAKH0>8XVW_HH5*A>_PS]QE\1<9```3
M"8G_EWD``(.YB1:BA4J%[_`OVQ7!$D>#MPD`#@>ZEYAGF.-EUYAKH0>8XVW_
MHH5*A>_P#]EE\1<9```3"4GTEWD``(.YR1*BA4J%[_!OUQ7!$D>#MPD`#@>Z
MEYAGF.-EUYAKH0>8XVW_HH5*A>_P3]5E\1<9```3"0GYEWD``(.Y"0^BA4J%
M[_"OTQ7!$D>#MPD`#@>ZEYAGF.-EUYAKH0>8XVW_HH5*A>_PC]%E\1<9```3
M"4GVEWD``(.Y20NBA4J%[_#OSQ7!$D>#MPD`#@>ZEYAGF.-EUYAKH0>8XVW_
MHH5*A>_PS\UE\1<9```3"8GSEWD``(.YB0>BA4J%[_`OS!7!$D>#MPD`#@>Z
MEYAGF.-EUYAKH0>8XVW_HH5*A>_P#\IE\1<9```3"4GFEWD``(.YR0.BA4J%
M[_!OR!7!$D>#MPD`#@>ZEYAGF.-EUYAKH0>8XVW_HH5*A>_P3\9E\:*%%Q4`
M`!,%Y>SO\$_%JH49Q1<5```3!>7I[_`O^:*%%Q4``!,%A>SO\&_#JH49Q1<5
M```3!07M[_!/]Z*%%Q4``!,%)>WO\(_!JH4%S1<5```3!:7<[_!O]2)GG&"Y
MCP%'J>-"=.)PHG0">>)IEQ4``).%I>P7%0``$P6EX"%A;_#/\J*%%Q4``!,%
MI>GO\`^]JH5YT1<5```3!:7@[_#O\&6_[]#?[@$1(N@&[!=T```#-*3T3``7
M%0``$P6%WAQ@/N2!1^_PC[D5P8-'!0`!18G'DX<'_3,U\``B9QQ@N8\!1YGG
MXF!"9`5A@H`!1?6W[]#_Z1UQ!NPJCA=U```#-<7S"&$3`X$"+O0R^#;\ON2Z
MX,+HQNR7=P``@[<'[IJ&<H:)19AC.N0!1QK@[]`_O1,%\`_OT+^X67&B\,%R
M063.Y-+@9NR&]*;LRNA6_%KX7O1B\!,'A``6D0J7EWP``(.\K.F#MPP`'..!
M1PE&@44JBN_0W\F3"?7_$]?Y0T&3LX?I`,(7P9.9C[.)^4!CQPD*P73!%),'
M!`'!:Z:7_5JSA"<`H0L=3!=Y```3">G!07L!1LZ%4H7OT'_%8PA5"5Z&IH52
MA>_0G]$!)6,*50=C<ZP&814SA*0`8W:4`*&H?11C:I0$(4;*A2*%[]`_OV7Y
MP7=!9\$700<^E[,')P`S!?1`3I7!9Z$'BI>88X.W#`"YCP%'J>/!8A:1IG`&
M=.9D1FFF:09JXGI">Z)[`GSB;&5A@H#:F>.=:?=]5>&W%Q4``!,%Y=#O\-_J
M%Q4``!,%)<_O\!_J[]!_TT$1!N3OT/^?`27OT)_+$<$(8:)@00&"@#EQ)O1*
M\`;\%WD```,YJ=>JA$P`%Q4``!,%9<V#-PD`/N2!1^_P3YP=Q2+X@T<%`"J$
MC<.FA>_07Z<=S2)G@S<)`+F/`4?9XT)TXG"B=`)Y(6&"@$)T(F>#-PD`N8\!
M1Z:%%Q4``!,%A<BEY^)PHG0">2%A;_`OS":%3NSOT/^7JHDBA>_0?Y>JF8D)
M3H7OT-^7(HB7%P``DX?GLB:'EQ8``).&1K-.AHE%*H3OT/_`(F>#-PD`N8\!
M1Y'KHH7B:4)T%Q4``!,%A<)-MT[L[]#?Q"+X3NSOT%_$EW<``).'AZ=)<8.X
M!P$#N(<!D'.4=YA[G'^F[LKJSN:&]J+REWD``(.Y2<@#LPD`&N8!0Q<3```3
M`T._9`@^X9<7``"3AP>_*HF:X#[T%Q,``!,#(Z>7%P``DX<GOJ:%%Q4``!,%
MA:::Y(+HQNS"\++TMOBZ_#[X`OSO\$^)$<6#1P4`*H1CE`<VTN)6_EKZ7O9B
M\N_0WX<!)>_0?[-C"@48@SH%`&.&"AA6A>_07X<3%!4`!00BA>_0GX<#QPH`
MJHLBC"J*#<\7&P``$PL+N-J&(H:)15Z%[]"?L(4*XH9C<XP`HH:SAX9`B0=C
M\]<`MH<#QPH`>105C#Z4B0MI^Y,*@047%0``$P7%JBF@`[6*`*$*#<&FA>_@
M?_\JA&79@T<%`.W7[_!/B771(H7OT#^?*H05X9,*`00#M`H`"<R#1P0`8X4'
M#B*%[_`/AV'I`[2*`*$*;?0BA>_0;_RJBE*%[]#O^[N*J@";BDI`5H7OT`_\
MEQ<``).'QY?2B!<8```3""BM(H>7%@``DX8&K5:&B44JB^_0OZ23!0`<6H7O
MT!^6_5=C&/4`[]!O^AQ!14=CGN<@9NZ3#($(YH5:A>_0'YHJA!GEZD>]9A%G
M]8]CAN<*EW<``(.W1[&#-@D`B&-:AQ<6```3!D:LB47OT#^=\FP!2C)G@[<)
M`+F/`4=CF`<NMG`6=/)Z4GNR>Q)\]F16:;9I4H46:G5A@H`BA>_0'Y`JA*$*
MXPD%\#6W`40EMR)U(!`9R::%[^!?[0'%@T<%`)7C"&0A!'WU-47OT"_NJHLJ
MBC5,-427&@``DXIJG!,',`6-M>_0GXNJBF'=[]`/ZQ,4%0`%!#6]"EKOT"_I
MFP<%`.,7^O3J1Q,'`!R3]_<?XY#G]%:%[]!OZ::%*HH7%0``$P7EI>_@7^:J
MA6,!!18#-0D`[_#OQ"J,8PH%%&*%[]#/Y9L+!0"-1V/8=P,3A<O_EQ4``).%
M):-BE>_0#_D)[9%'8XC[')N'N__BEP/'!P"3!_`"8P_W&J:%%Q4``!,%!87O
MX'_@8P8%$(-'!0!C@@<0$P<``V..YPZ7%0``DX6%C!<5```3!86"[_#/DN_0
MS_(JB)<8``"3B&BLEP<``).'YWI:AY<6``"3AL:>5H:)15*%[]!_B/U414F7
M'```DXSLJ1<,```3#&QXEQL``).+:YTEH._03]T<06.7)P/OT*_M!20JB&;@
MHHCBAUJ'WH96AHE%4H7OT#^$DP4`'%*%[]"/]>,(E?Q:A>_0[_+2A1<%```3
M!05Q[_#/B5*%[_`?MO)L+;47=P```S>GD8,V"0`(8Q<6```3!L:(6H>)1>_0
MC_TAM>_PG[,R9X.W"0"YCP%'8YT'#B*%%G2V</9D5FFV:75A;]`O\0,\"0!U
MM8%%8H7OT%^#JH3C#P7N[_!?G"J)XTH%[I,%9?\!1B:%[]"/Z),+`0(91MZ%
M)H7OT*_TF4=C'/4(`E>W1T%#DX<',.,3]^P#UTL`D6>3AX=4XQSWZ@%&DP7I
M_":%[]#/Y!,&@`+FA2:%[]`/\9,'@`)C'O4$EQ@``).(2)=FB)<'``"3AZ=E
M6H>7%@``DX:&B%:&B452A2,(`0KOT._R[;T#.8D`XP$)Y$J%[]#OQ8U'X_NG
MXG$5EQ4``).%)81*E>_0C]GC$07B2HPQO1<5```3!46#[_"_BV;N[]#O]-+B
M5OY:^E[V8O)F[N_0[_,Y<2+X%V0```,T9'Q*\$[L!OPF]%+HLP=$`(1CDPE!
M`!=I```#.2EX@\<$"\Z%%P4``!,%Q5\#-PD`.N0!1Z.(]`KOX'^\&<4#1P4`
MDP<0`V,+]Q+O\&_*LP=$`(1C)H6-1@5&EP4``).%97_OT._!JH0=P1QI,P=$
M``ACC&,7!@``$P9&?N_03\&<:(QCW$43EY<"8T8'$+,'1`"(8XU&!4:7!0``
MDX6%?._0#[ZJA!=J```3"JIU#<'.A1<%```3!651[^!?M"J&><&<:#,'1``(
M8XQC[]!/O+,'1`"$8P5&EP4``).%!7DFA>_0[Z^JA1<&```3!H9Y)H7OT.^Y
M$I0<8,Z%%P4``!,%Q4NCB`<*[^!_KR,XJ@`JA#G%DP4`'"*%[]!OS1L'%0"%
M1V/PYP+%1V,-]0"#-XH`JH8BAHQC%P4``!,%A7?OT`_2(F>#-PD`N8\!1['K
MXG!"=*)T`GGB:4)J(6&"@`,UB@#O\-^8(SBJ`"J$7?$7!0``$P6%<>_0C\Z#
M1Q4`XXH'[-FU`S>*`)QH#&.(8^_@?\TUO[,'1`"(8^_03\G]M>_0[]AY<2+P
M)NQ*Z`;T%VD```,YB5Z#-PD`/N2!1ZJ$[_#/HI,%\`(JA._03\<9P1,$%0`B
MA>_0C\,JA$P`%P4``!,%!4;OX'^A`<V#1P4`B<L3!P`#8X;G`('$@\<$`(GO
M(F>#-PD`N8\!1Y7OHG`"=.)D0FE%88*`$4:7!0``DX4E4B*%[]"/FF'](F>#
M-PD`N8\!1XGK`G2B<$)I)H7B9$5A;^#_J^_0;\Y!$1,%``@&Y._0KYRW=EU,
M-W?I8;<E16>3A14PA@8W5C(0!@<,X9.&YL^710``@[4%0A,&9D<3!P<?#.44
MZ1#M&/$C-`4"(S@%`B,L!0:B8$$!@H`Y<2+X)O1*\%;D!OQ.[%+H&'63%S8`
M%'FZEX(7@9,SM^<`JH2ZEBA=$U?6`3:7G/28^#*)+H23BH0#,>V3!_`#8]PG
M"1L)"?P;6FD`FPD:`)H)HIFBA1,&``16A>_0+Z03!`0$)H7OT,_HXQ4T_QL:
M:@`["4E!2H;.A5:%[]`OHB.L)`?B<$)THG0">>)I0FJB:B%A@H"3"0`$NX>I
M0+Z)8TKV`AN*"0"3BH0#4H:BA5:5[]#/GKQ<$P<`!+N&^0"TW..1YOPFA3L)
M.4%2E._03^*MM[*)^;>BB7&_>7$B\";L4N`&]$KH3N2#N84"$XJ%`Y,&`/@3
MUCD`$W;V`S,'R@`#N04#DP<6`",`UP`3!X`#+H2JA`4F8U?W$A,'``01GY%&
M,P7Z`&-UUQ2)1V-Y]Q)C%`<2(H7OT*_;$P:``X%%4H7OT*^JDU8)`1-7B0"3
M]O8/H@:;5XD!$W?W#T('U8\3>?D/8@G9CQO6B0&3U@D!`A:SYR<!$]>)`)/V
M]@^B%M&/$W?W#T(7U8_B&=F/L^<W`3SX(H7OT*_5'&`BA>&#(X#T`!Q@P8.C
M@/0`'&"A@R.!]``<8*.!]``<9.&#(X+T`!QDP8.C@O0`'&2A@R.#]``<9*.#
M]``<:.&#(X3T`!QHP8.CA/0`'&BA@R.%]``<:*.%]``<;.&#(X;T`!QLP8.C
MAO0`'&RA@R.']``<;*.']``<<.&#(XCT`!QPP8.CB/0`''"A@R.)]``<<*.)
M]``"=*)PXF1"::)I`FI%86_0SXX3!X`#.P;'0(%%,P7Z`._0KYG%O2,`!0#A
MO2,`!0"C``4`>1<)!>,%!^SMMR,`!0"C``4`(P$%`*,!!0!Q%XE'$07C9??J
MT;^79@``@[8&`V_`G_H``````0`"```````E<R\E<P```$1Y;F%,;V%D97(Z
M.F)O;W1?1'EN84QO861E<@``````26YT97)N86QS.CI005(Z.D)/3U0`````
M+W!R;V,O<V5L9B]E>&4``&5X90``````+W!R;V,O)6DO)7,``````"X`````
M````4$%27U1%35```````````%!!4E]04D]'3D%-10`````Z`````````"\`
M````````)7,E<R5S``!015),-4Q)0@``````````4$523$Q)0@!015),-4]0
M5```````````4$523$E/``!005)?24Y)5$E!3$E:140`4$%27U-005=.140`
M`````%!!4E]#3$5!3@````````!005)?1$5"54<`````````4$%27T-!0TA%
M`````````%!!4E]'3$]"04Q?1$5"54<``````````%!!4E]'3$]"04Q?5$U0
M1$E2`````````%!!4E]435!$25(```````!005)?1TQ/0D%,7U1%35``4$%2
M7T=,3T)!3%]#3$5!3@``````````,0````````!L<V5E:R!F86EL960`````
M<F5A9"!F86EL960``````$Q$7TQ)0E)!4EE?4$%42`!365-414T``"]T;7``
M````55-%4@````!54T523D%-10``````````)3`R>`````!P87(M`````"5S
M)7,E<R5S```````````E<SH@8W)E871I;VX@;V8@<')I=F%T92!S=6)D:7)E
M8W1O<GD@)7,@9F%I;&5D("AE<G)N;STE:2D*````````)7,Z('!R:79A=&4@
M<W5B9&ER96-T;W)Y("5S(&ES('5N<V%F92`H<&QE87-E(')E;6]V92!I="!A
M;F0@<F5T<GD@>6]U<B!O<&5R871I;VXI"@```````%!!5$@`````<&%R;```
M```N<&%R`````'-H;W)T(')E860````````E<R5S8V%C:&4M)7,E<P``)7,E
M<W1E;7`M)74E<P```"5S)7-T96UP+25U+25U)7,``````````!@`````````
M<&5R;``````P`````````%!!4CHZ4&%C:V5R.CI615)324].`````#$N,#4Y
M````56YA8FQE('1O(&-R96%T92!C86-H92!D:7)E8W1O<GD``````````"5S
M.B!C<F5A=&EO;B!O9B!P<FEV871E(&-A8VAE('-U8F1I<F5C=&]R>2`E<R!F
M86EL960@*&5R<FYO/25I*0H``````````"UE````````+2T```````!E=F%L
M("=E>&5C("]U<W(O8FEN+W!E<FP@("U3("0P("1[,2LB)$`B?2<*:68@,#L@
M(R!N;W0@<G5N;FEN9R!U;F1E<B!S;VUE('-H96QL"G!A8VMA9V4@7U]P87)?
M<&P["FUY("@D4$%27TU!1TE#+"`D1DE,15]O9F9S971?<VEZ92P@)&-A8VAE
M7VYA;65?<VEZ92D["D)%1TE.('L*)%!!4E]-04=)0R`](")<;E!!4BYP;5QN
M(CL*)$9)3$5?;V9F<V5T7W-I>F4@/2`T.R`@(",@<&%C:R@B3B(I"B1C86-H
M95]N86UE7W-I>F4@/2`T,#L*)%!+6DE07TU!1TE#(#T@(E!+7#`P,UPP,#0B
M.PI]"G-U8B!F:6YD7W!A<E]M86=I8PI["FUY("@D9F@I(#T@0%\["FUY("1C
M:'5N:U]S:7IE(#T@-C0@*B`Q,#(T.PIM>2`D8G5F.PIM>2`D<VEZ92`]("US
M("1F:#L*;7D@)'!O<R`]("@D<VEZ92TQ*2`M("@D<VEZ92TQ*2`E("1C:'5N
M:U]S:7IE.R`@("`@(",@3D]413H@)'!O<R!I<R!A(&UU;'1I<&QE(&]F("1C
M:'5N:U]S:7IE"G=H:6QE("@D<&]S(#X](#`I('L*<V5E:R`D9F@L("1P;W,L
M(#`["G)E860@)&9H+"`D8G5F+"`D8VAU;FM?<VEZ92`K(&QE;F=T:"@D4$%2
M7TU!1TE#*3L*:68@*"AM>2`D:2`](')I;F1E>"@D8G5F+"`D4$%27TU!1TE#
M*2D@/CT@,"D@>PIR971U<FX@)'!O<R`K("1I.PI]"B1P;W,@+3T@)&-H=6YK
M7W-I>F4["GT*<F5T=7)N("TQ.PI]"FUY("@D<&%R7W1E;7`L("1P<F]G;F%M
M92P@0'1M<&9I;&4L("5-;V1U;&5#86-H92D["D5.1"![(&EF("@D14Y6>U!!
M4E]#3$5!3GTI('L*<F5Q=6ER92!&:6QE.CI496UP.PIR97%U:7)E($9I;&4Z
M.D)A<V5N86UE.PIR97%U:7)E($9I;&4Z.E-P96,["FUY("1T;W!D:7(@/2!&
M:6QE.CI"87-E;F%M93HZ9&ER;F%M92@D<&%R7W1E;7`I.PIO=71S*'%Q6U)E
M;6]V:6YG(&9I;&5S(&EN("(D<&%R7W1E;7`B72D["D9I;&4Z.D9I;F0Z.F9I
M;F1D97!T:"AS=6(@>R`H("UD("D@/R!R;61I<B`Z('5N;&EN:R!]+"`D<&%R
M7W1E;7`I.PIR;61I<B`D<&%R7W1E;7`["FEF("@M9"`D<&%R7W1E;7`@)B8@
M)%Y/(&YE("=-4U=I;C,R)RD@>PIM>2`D=&UP(#T@;F5W($9I;&4Z.E1E;7`H
M"E1%35!,051%(#T^("=T;7!86%A86"<L"D1)4B`]/B!&:6QE.CI"87-E;F%M
M93HZ9&ER;F%M92@D=&]P9&ER*2P*4U5&1DE8(#T^("<N8VUD)RP*54Y,24Y+
M(#T^(#`L"BD["FUY("1F:6QE;F%M92`]("1T;7`M/F9I;&5N86UE.PIP<FEN
M="`D=&UP(#P\(BXN+B(["G@],3L@=VAI;&4@6R!<)'@@+6QT(#$P(%T[(&1O
M"G)M("UR9B`G)'!A<E]T96UP)PII9B!;(%PA("UD("<D<&%R7W1E;7`G(%T[
M('1H96X*8G)E86L*9FD*<VQE97`@,0IX/6!E>'!R(%PD>"`K(#%@"F1O;F4*
M<FT@)R1F:6QE;F%M92<*+BXN"F-L;W-E("1T;7`["F-H;6]D(#`W,#`L("1F
M:6QE;F%M93L*;7D@)&-M9"`]("(D9FEL96YA;64@/B]D978O;G5L;"`R/B8Q
M("8B.PIS>7-T96TH)&-M9"D["F]U=',H<7%;4W!A=VYE9"!B86-K9W)O=6YD
M('!R;V-E<W,@=&\@<&5R9F]R;2!C;&5A;G5P.B`D9FEL96YA;65=*3L*?0I]
M('T*0D5'24X@>PI);G1E<FYA;',Z.E!!4CHZ0D]/5"@I(&EF(&1E9FEN960@
M)DEN=&5R;F%L<SHZ4$%2.CI"3T]4.PIE=F%L('L*7W!A<E]I;FET7V5N=B@I
M.PIM>2`D<75I970@/2`A)$5.5GM005)?1$5"54=].PIM>2`E<WES(#T@*`IP
M871H7W-E<"`@("`]/B`H)%Y/(#U^("]>35-7:6XO(#\@)SLG(#H@)SHG*2P*
M7V5X92`@("`@("`@/3X@*"1>3R`]?B`O7B@_.DU35VEN?$]3,GQC>6=W:6XI
M+R`_("<N97AE)R`Z("<G*2P*7V1E;&EM("`@("`@/3X@*"1>3R`]?B`O7DU3
M5VEN?$]3,B\@/R`G7%PG(#H@)R\G*2P**3L*7W-E=%]P<F]G;F%M92@I.PIO
M=71S*'%Q6UPD<')O9VYA;64@/2`B)'!R;V=N86UE(ETI.PI?<V5T7W!A<E]T
M96UP*"D["F]U=',H<7%;7"1%3E9[4$%27U1%35!](#T@(B1%3E9[4$%27U1%
M35!](ETI.PIM>2`H)'-T87)T7W!O<RP@)'-T87)T7V]F7T9)3$5?<V5C=&EO
M;BD["DU!1TE#.B!["FQO8V%L("1324=[7U]705).7U]](#T@<W5B('M].PIU
M;FQE<W,@*&]P96X@7T9(+"`G/#IR87<G+"`D<')O9VYA;64I('L*;W5T<RAQ
M<5M#86XG="!R96%D(&9R;VT@9FEL92`B)'!R;V=N86UE(ETI.R`@(R!D;VXG
M="!U<V4@)"$@:&5R92!A<R!I="!R97%U:7)E<R!%<G)N;RYP;0IL87-T($U!
M1TE#.PI]"FUY("1M86=I8U]P;W,@/2!F:6YD7W!A<E]M86=I8R@J7T9(*3L*
M:68@*"1M86=I8U]P;W,@/"`P*2!["F]U=',H<7%;0V%N)W0@9FEN9"!M86=I
M8R!S=')I;F<@(B1005)?34%'24,B(&EN(&9I;&4@(B1P<F]G;F%M92)=*3L*
M;&%S="!-04=)0SL*?0IO=71S*")&;W5N9"!005(@;6%G:6,@870@<&]S:71I
M;VX@)&UA9VEC7W!O<R(I.PIS965K(%]&2"P@)&UA9VEC7W!O<R`M("1&24Q%
M7V]F9G-E=%]S:7IE("T@;&5N9W1H*")<,$-!0TA%(BDL(#`["G)E860@7T9(
M+"`D8G5F+"!L96YG=&@H(EPP0T%#2$4B*3L*:68@*"1B=68@;F4@(EPP0T%#
M2$4B("8F("1B=68@;F4@(EPP0TQ%04XB*2!["F]U=',H(DYO(&-A8VAE(&UA
M<FME<B!F;W5N9"(I.PIL87-T($U!1TE#.PI]"F]U=',H<7%;0V%C:&4@;6%R
M:V5R("(D8G5F(B!F;W5N9%TI.PIS965K(%]&2"P@)&UA9VEC7W!O<R`M("1&
M24Q%7V]F9G-E=%]S:7IE+"`P.PIR96%D(%]&2"P@)&)U9BP@)$9)3$5?;V9F
M<V5T7W-I>F4["FUY("1O9F9S970@/2!U;G!A8VLH(DXB+"`D8G5F*3L*;W5T
M<R@B3V9F<V5T(&9R;VT@<W1A<G0@;V8@1DE,17,@:7,@)&]F9G-E="(I.PIS
M965K(%]&2"P@)&UA9VEC7W!O<R`M("1&24Q%7V]F9G-E=%]S:7IE("T@)&]F
M9G-E="P@,#L*)'-T87)T7V]F7T9)3$5?<V5C=&EO;B`]('1E;&P@7T9(.PIM
M>2`E<F5Q=6ER95]L:7-T.PIR96%D(%]&2"P@)&)U9BP@-#L@("`@("`@("`@
M("`@("`@("`@("`@("`@("`C(')E860@=&AE(&9I<G-T(")&24Q%(@IW:&EL
M92`H)&)U9B!E<2`B1DE,12(I('L*<F5A9"!?1D@L("1B=68L(#0["G)E860@
M7T9(+"`D8G5F+"!U;G!A8VLH(DXB+"`D8G5F*3L*;7D@)&9U;&QN86UE(#T@
M)&)U9CL*;W5T<RAQ<5M5;G!A8VMI;F<@1DE,12`B)&9U;&QN86UE(BXN+ETI
M.PIM>2`D8W)C(#T@*"`D9G5L;&YA;64@/7X@<WQ>*%MA+69<9%U[.'TI+WQ\
M("D@/R`D,2`Z('5N9&5F.PIM>2`H)&)A<V5N86UE+"`D97AT*2`]("@D8G5F
M(#U^(&U\*#\Z+BHO*3\H+BHI*%PN+BHI?"D["G)E860@7T9(+"`D8G5F+"`T
M.PIR96%D(%]&2"P@)&)U9BP@=6YP86-K*").(BP@)&)U9BD["FEF("AD969I
M;F5D*"1E>'0I(&%N9"`D97AT("%^("]<+B@_.G!M?'!L?&EX?&%L*20O:2D@
M>PIM>2`D9FEL96YA;64@/2!?<V%V95]A<R@B)&-R8R1E>'0B+"`D8G5F+"`P
M-S4U*3L*)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD9G5L;&YA;65](#T@)&9I
M;&5N86UE.PHD4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1F:6QE;F%M97T@/2`D
M9G5L;&YA;64["GT*96QS92!["B1-;V1U;&5#86-H97LD9G5L;&YA;65](#T@
M>PIB=68@/3X@)&)U9BP*8W)C(#T^("1C<F,L"FYA;64@/3X@)&9U;&QN86UE
M+`I].PHD<F5Q=6ER95]L:7-T>R1F=6QL;F%M97TK*SL*?0IR96%D(%]&2"P@
M)&)U9BP@-#L*?0IL;V-A;"!`24Y#(#T@*'-U8B!["FUY("@D<V5L9BP@)&UO
M9'5L92D@/2!`7SL*<F5T=7)N(&EF(')E9B`D;6]D=6QE(&]R("$D;6]D=6QE
M.PIM>2`D:6YF;R`]("1-;V1U;&5#86-H97LD;6]D=6QE?3L*<F5T=7)N('5N
M;&5S<R`D:6YF;SL*9&5L971E("1R97%U:7)E7VQI<W1[)&UO9'5L97T["B1)
M3D-[)&UO9'5L97T@/2`B+VQO861E<B\D:6YF;R\D;6]D=6QE(CL*:68@*"1%
M3E9[4$%27T-,14%.?2!A;F0@9&5F:6YE9"@F24\Z.D9I;&4Z.FYE=RDI('L*
M;7D@)&9H(#T@24\Z.D9I;&4M/FYE=U]T;7!F:6QE(&]R(&1I92`B0V%N)W0@
M8W)E871E('1E;7`@9FEL93H@)"$B.PHD9F@M/F)I;FUO9&4H*3L*)&9H+3YP
M<FEN="@D:6YF;RT^>V)U9GTI.PHD9F@M/G-E96LH,"P@,"D["G)E='5R;B`D
M9F@["GT*96QS92!["FUY("1F:6QE;F%M92`](%]S879E7V%S*"(D:6YF;RT^
M>V-R8WTN<&TB+"`D:6YF;RT^>V)U9GTI.PHD:6YF;RT^>V9I;&5](#T@)&9I
M;&5N86UE.PIO<&5N(&UY("1F:"P@)SPZ<F%W)RP@)&9I;&5N86UE(&]R(&1I
M92!Q<5M#86XG="!R96%D("(D9FEL96YA;64B.B`D(5T["G)E='5R;B`D9F@[
M"GT*9&EE(")";V]T<W1R87!P:6YG(&9A:6QE9#H@8V%N)W0@9FEN9"!M;V1U
M;&4@)&UO9'5L92$B.PI]+"!`24Y#*3L*<F5Q=6ER92!84TQO861E<CL*<F5Q
M=6ER92!005(Z.DAE879Y.PIR97%U:7)E($-A<G`Z.DAE879Y.PIR97%U:7)E
M($5X<&]R=&5R.CI(96%V>3L*4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E
M<B@I.PIR97%U:7)E($E/.CI&:6QE.PIW:&EL92`H;7D@)&9I;&5N86UE(#T@
M*'-O<G0@:V5Y<R`E<F5Q=6ER95]L:7-T*5LP72D@>PIU;FQE<W,@*"1)3D-[
M)&9I;&5N86UE?2!O<B`D9FEL96YA;64@/7X@+T)31%!!3B\I('L*:68@*"1F
M:6QE;F%M92`]?B`O7"YP;6,_)"]I*2!["G)E<75I<F4@)&9I;&5N86UE.PI]
M"F5L<V4@>PID;R`D9FEL96YA;64@=6YL97-S("1F:6QE;F%M92`]?B`O<VET
M96-U<W1O;6EZ95PN<&PD+SL*?0I]"F1E;&5T92`D<F5Q=6ER95]L:7-T>R1F
M:6QE;F%M97T["GT*:68@*"1B=68@;F4@)%!+6DE07TU!1TE#*2!["F]U=',H
M<7%;3F\@>FEP(&9O=6YD(&%F=&5R($9)3$4@<V5C=&EO;B!I;B!F:6QE("(D
M<')O9VYA;64B72D["FQA<W0@34%'24,@.PI]"B1S=&%R=%]P;W,@/2`H=&5L
M;"!?1D@I("T@-#L@("`@("`@("`@("`@("`@(R!S=&%R="!O9B!Z:7`*?0IM
M>2!`<&%R7V%R9W,["FUY("@D;W5T+"`D8G5N9&QE+"`D;&]G9F@L("1C86-H
M95]N86UE*3L*9&5L971E("1%3E9[4$%27T%04%]2155317T[(",@<V%N:71I
M>F4@*%)%55-%(&UA>2!B92!A('-E8W5R:71Y('!R;V)L96TI"FEF("@A)'-T
M87)T7W!O<R!O<B`H)$%21U9;,%T@97$@)RTM<&%R+6]P=&EO;G,G("8F('-H
M:69T*2D@>PIM>2`E9&ES=%]C;60@/2!Q=R@*<"`@(&)L:6)?=&]?<&%R"FD@
M("!I;G-T86QL7W!A<@IU("`@=6YI;G-T86QL7W!A<@IS("`@<VEG;E]P87(*
M=B`@('9E<FEF>5]P87(**3L*:68@*$!!4D=6(&%N9"`D05)'5ELP72!E<2`G
M+2UR975S92<I('L*<VAI9G0@0$%21U8["B1%3E9[4$%27T%04%]2155317T@
M/2!S:&EF="!`05)'5CL*?0IE;'-E('L@(R!N;W)M86P@<&%R;"!B96AA=FEO
M=7(*;7D@0&%D9%]T;U]I;F,["G=H:6QE("A`05)'5BD@>PHD05)'5ELP72`]
M?B`O7BTH6T%)34]"3&)Q<&EU<U1V72DH+BHI+R!O<B!L87-T.PII9B`H)#$@
M97$@)TDG*2!["G!U<V@@0&%D9%]T;U]I;F,L("0R.PI]"F5L<VEF("@D,2!E
M<2`G32<I('L*979A;"`B=7-E("0R(CL*?0IE;'-I9B`H)#$@97$@)T$G*2![
M"G5N<VAI9G0@0'!A<E]A<F=S+"`D,CL*?0IE;'-I9B`H)#$@97$@)T\G*2![
M"B1O=70@/2`D,CL*?0IE;'-I9B`H)#$@97$@)V(G*2!["B1B=6YD;&4@/2`G
M<VET92<["GT*96QS:68@*"0Q(&5Q("=")RD@>PHD8G5N9&QE(#T@)V%L;"<[
M"GT*96QS:68@*"0Q(&5Q("=Q)RD@>PHD<75I970@/2`Q.PI]"F5L<VEF("@D
M,2!E<2`G3"<I('L*;W!E;B`D;&]G9F@L("(^/B(L("0R(&]R(&1I92!Q<5M#
M86XG="!O<&5N(&QO9R!F:6QE("(D,B(Z("0A73L*?0IE;'-I9B`H)#$@97$@
M)U0G*2!["B1C86-H95]N86UE(#T@)#(["GT*<VAI9G0H0$%21U8I.PII9B`H
M;7D@)&-M9"`]("1D:7-T7V-M9'LD,7TI('L*9&5L971E("1%3E9[)U!!4E]4
M14U0)WT["FEN:71?:6YC*"D["G)E<75I<F4@4$%2.CI$:7-T.PHF>R)005(Z
M.D1I<W0Z.B1C;60B?2@I('5N;&5S<R!`05)'5CL*)GLB4$%2.CI$:7-T.CHD
M8VUD(GTH)%\I(&9O<B!`05)'5CL*97AI=#L*?0I]"G5N<VAI9G0@0$E.0RP@
M0&%D9%]T;U]I;F,["GT*?0II9B`H)&]U="D@>PI["G)E<75I<F4@24\Z.D9I
M;&4["G)E<75I<F4@07)C:&EV93HZ6FEP.PIR97%U:7)E($1I9V5S=#HZ4TA!
M.PI]"FUY("1P87(@/2!S:&EF="A`05)'5BD["FUY("1Z:7`["FEF("AD969I
M;F5D("1P87(I('L*;W!E;B!M>2`D9F@L("<\.G)A=R<L("1P87(@;W(@9&EE
M('%Q6T-A;B=T(&9I;F0@<&%R(&9I;&4@(B1P87(B.B`D(5T["F)L97-S*"1F
M:"P@)TE/.CI&:6QE)RD["B1Z:7`@/2!!<F-H:79E.CI::7`M/FYE=SL**"`D
M>FEP+3YR96%D1G)O;49I;&5(86YD;&4H)&9H+"`D<&%R*2`]/2!!<F-H:79E
M.CI::7`Z.D%:7T]+*"D@*0IO<B!D:64@<7%;17)R;W(@<F5A9&EN9R!Z:7`@
M87)C:&EV92`B)'!A<B)=.PI]"FUY("5M971A7W!A<B`](&1O('L*:68@*"1Z
M:7`@86YD(&UY("1M971A(#T@)'II<"T^8V]N=&5N=',H)TU%5$$N>6UL)RDI
M('L*)&UE=&$@/7X@<R\N*EYP87(Z)"\O;7,["B1M971A(#U^(',O7EQ3+BHO
M+VUS.PHD;65T82`]?B`O7B`@*%M>.ETK*3H@*"XK*20O;6<["GT*?3L*:68@
M*&1E9FEN960@)'!A<BD@>PIO<&5N(&UY("1P:"P@)SPZ<F%W)RP@)'!A<B!O
M<B!D:64@<7%;0V%N)W0@<F5A9"!P87(@9FEL92`B)'!A<B(Z("0A73L*;7D@
M)&)U9CL*<F5A9"`D<&@L("1B=68L(#0["F1I92!Q<5LB)'!A<B(@:7,@;F]T
M(&$@<&%R(&9I;&5=('5N;&5S<R`D8G5F(&5Q("102UI)4%]-04=)0SL*8VQO
M<V4@)'!H.PI]"D-R96%T95!A=&@H)&]U="D@.PIM>2`D9F@@/2!)3SHZ1FEL
M92T^;F5W*`HD;W5T+`I)3SHZ1FEL93HZ3U]#4D5!5"@I('P@24\Z.D9I;&4Z
M.D]?4D174B@I('P@24\Z.D9I;&4Z.D]?5%)53D,H*2P*,#<W-RP**2!O<B!D
M:64@<7%;0V%N)W0@8W)E871E(&9I;&4@(B1O=70B.B`D(5T["B1F:"T^8FEN
M;6]D92@I.PIS965K(%]&2"P@,"P@,#L*;7D@)&QO861E<CL*:68@*&1E9FEN
M960@)'-T87)T7V]F7T9)3$5?<V5C=&EO;BD@>PIR96%D(%]&2"P@)&QO861E
M<BP@)'-T87)T7V]F7T9)3$5?<V5C=&EO;CL*?2!E;'-E('L*;&]C86P@)"\@
M/2!U;F1E9CL*)&QO861E<B`](#Q?1D@^.PI]"FEF("@A)$5.5GM005)?5D52
M0D%424U](&%N9"`D;&]A9&5R(#U^("]>*#\Z(R%\7$!R96TI+RD@>PIR97%U
M:7)E(%!!4CHZ1FEL=&5R.CI0;V13=')I<#L*4$%2.CI&:6QT97(Z.E!O9%-T
M<FEP+3YA<'!L>2A<)&QO861E<BP@)#`I.PI]"B1F:"T^<')I;G0H)&QO861E
M<BD*;W(@9&EE('%Q6T5R<F]R('=R:71I;F<@;&]A9&5R('1O("(D;W5T(CH@
M)"%=.PII9B`H)&)U;F1L92D@>PIR97%U:7)E(%!!4CHZ2&5A=GD["E!!4CHZ
M2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*:6YI=%]I;F,H*3L*<F5Q=6ER
M95]M;V1U;&5S*"D["FUY($!I;F,@/2!G<F5P('L@(2]"4T1004XO('T*9W)E
M<"!["B@D8G5N9&QE(&YE("=S:71E)RD@;W(**"1?(&YE("1#;VYF:6<Z.D-O
M;F9I9WMA<F-H;&EB97AP?2!A;F0*)%\@;F4@)$-O;F9I9SHZ0V]N9FEG>W!R
M:79L:6)E>'!]*3L*?2!`24Y#.PIS?"\K?"]\9RP@<WPO)'Q\(&9O<F5A8V@@
M0&EN8SL*;7D@)69I;&5S.PHD9FEL97-[)%]]*RL@9F]R($!$>6YA3&]A9&5R
M.CID;%]S:&%R961?;V)J96-T<RP@=F%L=65S("5)3D,["FUY("1L:6)?97AT
M(#T@)$-O;F9I9SHZ0V]N9FEG>VQI8E]E>'1].R`@("`@("`@(",@6%A8(&QI
M8E]E>'0@=G,@9&QE>'0@/PIM>2`E=W)I='1E;CL*9F]R96%C:"!M>2`D:V5Y
M("AS;W)T(&ME>7,@)69I;&5S*2!["FUY("@D9FEL92P@)&YA;64I.PII9B`H
M9&5F:6YE9"AM>2`D9F,@/2`D4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1K97E]
M*2D@>PHH)&9I;&4L("1N86UE*2`]("@D:V5Y+"`D9F,I.PI]"F5L<V4@>PIF
M;W)E86-H(&UY("1D:7(@*$!I;F,I('L*:68@*"1K97D@/7X@;7Q>7%$D9&ER
M7$4O*"XJ*21\:2D@>PHH)&9I;&4L("1N86UE*2`]("@D:V5Y+"`D,2D["FQA
M<W0["GT*:68@*"1K97D@/7X@;7Q>+VQO861E<B];7B]=*R\H+BHI)'PI('L*
M:68@*&UY("1R968@/2`D36]D=6QE0V%C:&5[)#%]*2!["B@D9FEL92P@)&YA
M;64I(#T@*"1R968L("0Q*3L*;&%S=#L*?0II9B`H+68@(B1D:7(O)#$B*2![
M"B@D9FEL92P@)&YA;64I(#T@*"(D9&ER+R0Q(BP@)#$I.PIL87-T.PI]"GT*
M?0I]"FYE>'0@=6YL97-S(&1E9FEN960@)&YA;64["FYE>'0@:68@)'=R:71T
M96Y[)&YA;65]*RL["FYE>'0@:68@(7)E9B@D9FEL92D@86YD("1F:6QE(#U^
M("]<+EQ1)&QI8E]E>'1<120O:3L*;W5T<RAS<')I;G1F*'%Q6U!A8VMI;F<@
M1DE,12`B)7,B+BXN72P@<F5F("1F:6QE(#\@)&9I;&4M/GMN86UE?2`Z("1F
M:6QE*2D["FUY("1C;VYT96YT.PII9B`H<F5F*"1F:6QE*2D@>PHD8V]N=&5N
M="`]("1F:6QE+3Y[8G5F?3L*?0IE;'-E('L*;&]C86P@)"\@/2!U;F1E9CL*
M;W!E;B!M>2`D=&@L("<\.G)A=R<L("1F:6QE(&]R(&1I92!Q<5M#86XG="!R
M96%D("(D9FEL92(Z("0A73L*)&-O;G1E;G0@/2`\)'1H/CL*8VQO<V4@)'1H
M.PI005(Z.D9I;'1E<CHZ4&]D4W1R:7`M/F%P<&QY*%PD8V]N=&5N="P@(CQE
M;6)E9&1E9#XO)&YA;64B*0II9B`A)$5.5GM005)?5D520D%424U](&%N9"`D
M;F%M92`]?B`O7"XH/SIP;7QI>'QA;"DD+VD["E!!4CHZ1FEL=&5R.CI0871C
M:$-O;G1E;G0M/FYE=RT^87!P;'DH7"1C;VYT96YT+"`D9FEL92P@)&YA;64I
M.PI]"B1F:"T^<')I;G0H(D9)3$4B+`IP86-K*"=.)RP@;&5N9W1H*"1N86UE
M*2`K(#DI+`IS<')I;G1F*"(E,#AX+R5S(BP@07)C:&EV93HZ6FEP.CIC;VUP
M=71E0U)#,S(H)&-O;G1E;G0I+"`D;F%M92DL"G!A8VLH)TXG+"!L96YG=&@H
M)&-O;G1E;G0I*2P*)&-O;G1E;G0I"F]R(&1I92!Q<5M%<G)O<B!W<FET:6YG
M(&5M8F5D9&5D($9)3$4@=&\@(B1O=70B.B`D(5T["F]U=',H<7%;5W)I='1E
M;B!A<R`B)&YA;64B72D["GT*?0II9B`H)'II<"D@>PHD>FEP+3YW<FET951O
M1FEL94AA;F1L92@D9F@I(#T]($%R8VAI=F4Z.EII<#HZ05I?3TL*;W(@9&EE
M('%Q6T5R<F]R('=R:71I;F<@>FEP('!A<G0@;V8@(B1O=70B73L*?0II9B`H
M)&UE=&%?<&%R>V-L96%N?2D@>PHD9F@M/G!R:6YT*")<,$-,14%.(BD["GT*
M96QS92!["FEF("@A9&5F:6YE9"`D8V%C:&5?;F%M92D@>PIM>2`D8W1X(#T@
M1&EG97-T.CI32$$M/FYE=R@Q*3L*<V5E:R`D9F@L(#`L(#`["B1C='@M/F%D
M9&9I;&4H)&9H*3L*<V5E:R`D9F@L(#`L(#(["B1C86-H95]N86UE(#T@)&-T
M>"T^:&5X9&EG97-T.PI]"B1C86-H95]N86UE(#T@<W5B<W1R("1C86-H95]N
M86UE+"`P+"`D8V%C:&5?;F%M95]S:7IE.PHD8V%C:&5?;F%M92`N/2`B7#`B
M('@@*"1C86-H95]N86UE7W-I>F4@+2!L96YG=&@@)&-A8VAE7VYA;64I.PHD
M9F@M/G!R:6YT*"1C86-H95]N86UE+`HB7#!#04-(12(I.PI]"FUY("1O9F9S
M970@/2`D9F@M/G1E;&P@+2!L96YG=&@H)&QO861E<BD["B1F:"T^<')I;G0H
M<&%C:R@G3B<L("1O9F9S970I+`HD4$%27TU!1TE#*3L*)&9H+3YC;&]S92!O
M<B!D:64@<7%;17)R;W(@=W)I=&EN9R!T<F%I;&5R(&]F("(D;W5T(CH@)"%=
M.PIC:&UO9"`P-S4U+"`D;W5T.PIE>&ET.PI]"GL*;&%S="!U;FQE<W,@9&5F
M:6YE9"`D<W1A<G1?<&]S.PI?9FEX7W!R;V=N86UE*"D["G)E<75I<F4@4$%2
M.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["GL*<F5Q=6ER92!&
M:6QE.CI&:6YD.PIR97%U:7)E($%R8VAI=F4Z.EII<#L*?0IM>2`D9F@@/2!)
M3SHZ1FEL92T^;F5W.R`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(R!!
M<F-H:79E.CI::7`@;W!E<F%T97,@;VX@86X@24\Z.DAA;F1L90HD9F@M/F9D
M;W!E;BAF:6QE;F\H7T9(*2P@)W(G*2!O<B!D:64@<7%;9F1O<&5N*"D@9F%I
M;&5D.B`D(5T["D%R8VAI=F4Z.EII<#HZ<V5T0VAU;FM3:7IE*"US(%]&2"D[
M"FUY("1Z:7`@/2!!<F-H:79E.CI::7`M/FYE=SL**"1Z:7`M/G)E861&<F]M
M1FEL94AA;F1L92@D9F@L("1P<F]G;F%M92D@/3T@07)C:&EV93HZ6FEP.CI!
M6E]/2R@I*0IO<B!D:64@<7%;17)R;W(@<F5A9&EN9R!Z:7`@87)C:&EV92`B
M)'!R;V=N86UE(ET["D%R8VAI=F4Z.EII<#HZ<V5T0VAU;FM3:7IE*#8T("H@
M,3`R-"D["G!U<V@@0%!!4CHZ3&EB0V%C:&4L("1Z:7`["B1005(Z.DQI8D-A
M8VAE>R1P<F]G;F%M97T@/2`D>FEP.PIO=71S*")%>'1R86-T:6YG('II<"XN
M+B(I.PII9B`H9&5F:6YE9"`D14Y6>U!!4E]414U0?2D@>R`C('-H;W5L9"!B
M92!S970@870@=&AI<R!P;VEN="$*9F]R96%C:"!M>2`D;65M8F5R("@@)'II
M<"T^;65M8F5R<R`I('L*;F5X="!I9B`D;65M8F5R+3YI<T1I<F5C=&]R>3L*
M;7D@)&UE;6)E<E]N86UE(#T@)&UE;6)E<BT^9FEL94YA;64["FYE>'0@=6YL
M97-S("1M96UB97)?;F%M92`]?B!M>PI>"B\_<VAL:6(O"B@_.B1#;VYF:6<Z
M.D-O;F9I9WMA<F-H;F%M97TO*3\**%M>+UTK*0HD"GUX.PIM>2`D97AT<F%C
M=%]N86UE(#T@)#$["FUY("1D97-T7VYA;64@/2!&:6QE.CI3<&5C+3YC871F
M:6QE*"1%3E9[4$%27U1%35!]+"`D97AT<F%C=%]N86UE*3L*:68@*"UF("1D
M97-T7VYA;64@)B8@+7,@7R`]/2`D;65M8F5R+3YU;F-O;7!R97-S9613:7IE
M*"DI('L*;W5T<RAQ<5M3:VEP<&EN9R`B)&UE;6)E<E]N86UE(B!S:6YC92!I
M="!A;')E861Y(&5X:7-T<R!A="`B)&1E<W1?;F%M92)=*3L*?2!E;'-E('L*
M;W5T<RAQ<5M%>'1R86-T:6YG("(D;65M8F5R7VYA;64B('1O("(D9&5S=%]N
M86UE(BXN+ETI.PHH)&UE;6)E<BT^97AT<F%C=%1O1FEL94YA;65D*"1D97-T
M7VYA;64I(#T]($%R8VAI=F4Z.EII<#HZ05I?3TLH*2D*;W(@9&EE('%Q6T5R
M<F]R(&5X=')A8W1I;F<@>FEP(&UE;6)E<B!T;R`B)&1E<W1?;F%M92)=.PIC
M:&UO9"@P-34U+"`D9&5S=%]N86UE*2!I9B`D7D\@97$@(FAP=7@B.PI]"GT*
M?0I]"G5N;&5S<R`H)%!!4CHZ3&EB0V%C:&5[)'!R;V=N86UE?2D@>PID:64@
M/#P@(BXB('5N;&5S<R!`05)'5CL*57-A9V4Z("0P(%L@+4%L:6(N<&%R(%T@
M6R`M261I<B!=(%L@+4UM;V1U;&4@72!;('-R8RYP87(@72!;('!R;V=R86TN
M<&P@70HD,"!;("U"?"UB(%T@6RU/;W5T9FEL95T@<W)C+G!A<@HN"B1%3E9[
M4$%27U!23T=.04U%?2`]("1P<F]G;F%M92`]("0P(#T@<VAI9G0H0$%21U8I
M.PI]"G-U8B!#<F5A=&50871H('L*;7D@*"1N86UE*2`]($!?.PIR97%U:7)E
M($9I;&4Z.D)A<V5N86UE.PIM>2`H)&)A<V5N86UE+"`D<&%T:"P@)&5X="D@
M/2!&:6QE.CI"87-E;F%M93HZ9FEL97!A<G-E*"1N86UE+"`H)UPN+BHG*2D[
M"G)E<75I<F4@1FEL93HZ4&%T:#L*1FEL93HZ4&%T:#HZ;6MP871H*"1P871H
M*2!U;FQE<W,H+64@)'!A=&@I.R`C(&UK<&%T:"!D:65S('=I=&@@97)R;W(*
M?0IS=6(@<F5Q=6ER95]M;V1U;&5S('L*<F5Q=6ER92!L:6(["G)E<75I<F4@
M1'EN84QO861E<CL*<F5Q=6ER92!I;G1E9V5R.PIR97%U:7)E('-T<FEC=#L*
M<F5Q=6ER92!W87)N:6YG<SL*<F5Q=6ER92!V87)S.PIR97%U:7)E($-A<G`[
M"G)E<75I<F4@0V%R<#HZ2&5A=GD["G)E<75I<F4@17)R;F\["G)E<75I<F4@
M17AP;W)T97(Z.DAE879Y.PIR97%U:7)E($5X<&]R=&5R.PIR97%U:7)E($9C
M;G1L.PIR97%U:7)E($9I;&4Z.E1E;7`["G)E<75I<F4@1FEL93HZ4W!E8SL*
M<F5Q=6ER92!84TQO861E<CL*<F5Q=6ER92!#;VYF:6<["G)E<75I<F4@24\Z
M.DAA;F1L93L*<F5Q=6ER92!)3SHZ1FEL93L*<F5Q=6ER92!#;VUP<F5S<SHZ
M6FQI8CL*<F5Q=6ER92!!<F-H:79E.CI::7`["G)E<75I<F4@1&EG97-T.CI3
M2$$["G)E<75I<F4@4$%2.PIR97%U:7)E(%!!4CHZ2&5A=GD["G)E<75I<F4@
M4$%2.CI$:7-T.PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0;V13=')I<#L*<F5Q
M=6ER92!005(Z.D9I;'1E<CHZ4&%T8VA#;VYT96YT.PIR97%U:7)E(&%T=')I
M8G5T97,["F5V86P@>R!R97%U:7)E($-W9"!].PIE=F%L('L@<F5Q=6ER92!7
M:6XS,B!].PIE=F%L('L@<F5Q=6ER92!38V%L87(Z.E5T:6P@?3L*979A;"![
M(')E<75I<F4@07)C:&EV93HZ56YZ:7`Z.D)U<G-T('T["F5V86P@>R!R97%U
M:7)E(%1I93HZ2&%S:#HZ3F%M961#87!T=7)E('T["F5V86P@>R!R97%U:7)E
M(%!E<FQ)3SL@<F5Q=6ER92!097)L24\Z.G-C86QA<B!].PIE=F%L('L@<F5Q
M=6ER92!U=&8X('T["GT*<W5B(%]S971?<&%R7W1E;7`@>PII9B`H9&5F:6YE
M9"`D14Y6>U!!4E]414U0?2!A;F0@)$5.5GM005)?5$5-4'T@/7X@+R@N*RDO
M*2!["B1P87)?=&5M<"`]("0Q.PIR971U<FX["GT*9F]R96%C:"!M>2`D<&%T
M:"`H"BAM87`@)$5.5GLD7WTL('%W*"!005)?5$U01$E2(%1-4$1)4B!414U0
M1$E2(%1%35`@5$U0("DI+`IQ=R@@0SI<7%1%35`@+W1M<"`N("D**2!["FYE
M>'0@=6YL97-S(&1E9FEN960@)'!A=&@@86YD("UD("1P871H(&%N9"`M=R`D
M<&%T:#L*;7D@)'5S97)N86UE.PIM>2`D<'=U:60["F5V86P@>R@D<'=U:60I
M(#T@9V5T<'=U:60H)#XI(&EF(&1E9FEN960@)#X[?3L*:68@*"!D969I;F5D
M*"97:6XS,CHZ3&]G:6Y.86UE*2`I('L*)'5S97)N86UE(#T@)E=I;C,R.CI,
M;V=I;DYA;64["GT*96QS:68@*&1E9FEN960@)'!W=6ED*2!["B1U<V5R;F%M
M92`]("1P=W5I9#L*?0IE;'-E('L*)'5S97)N86UE(#T@)$5.5GM54T523D%-
M17T@?'P@)$5.5GM54T52?2!\?"`G4UE35$5-)SL*?0IM>2`D<W1M<&1I<B`]
M("(D<&%T:"1S>7-[7V1E;&EM?7!A<BTB+G5N<&%C:R@B2"HB+"`D=7-E<FYA
M;64I.PIM:V1I<B`D<W1M<&1I<BP@,#<U-3L*;7D@)&-A8VAE7V1I<CL*:68@
M*"1%3E9[4$%27T-,14%.?2D@>PHD8V%C:&5?9&ER(#T@(G1E;7`M)"0B.PI]
M"F5L<V4@>PIO<&5N(&UY("1F:"P@(CPZ<F%W(BP@)'!R;V=N86UE(&]R(&1I
M92!Q<5M#86XG="!R96%D("(D<')O9VYA;64B.B`D(5T["FEF("@H;7D@)&UA
M9VEC7W!O<R`](&9I;F1?<&%R7VUA9VEC*"1F:"DI(#X](#`I('L*<V5E:R`D
M9F@L("1M86=I8U]P;W,*+2`D1DE,15]O9F9S971?<VEZ90HM(&QE;F=T:"@B
M7#!#04-(12(I+"`P.PIM>2`D8G5F.PIR96%D("1F:"P@)&)U9BP@;&5N9W1H
M*")<,$-!0TA%(BD["FEF("@D8G5F(&5Q(")<,$-!0TA%(BD@>PIS965K("1F
M:"P@)&UA9VEC7W!O<PHM("1&24Q%7V]F9G-E=%]S:7IE"BT@;&5N9W1H*")<
M,$-!0TA%(BD*+2`D8V%C:&5?;F%M95]S:7IE+"`P.PIR96%D("1F:"P@)&)U
M9BP@)&-A8VAE7VYA;65?<VEZ93L*)&)U9B`]?B!S+UPP+R]G.PHD8V%C:&5?
M9&ER(#T@(F-A8VAE+21B=68B.PI]"GT*8VQO<V4@)&9H.PI]"FEF("@A)&-A
M8VAE7V1I<BD@>PHD8V%C:&5?9&ER(#T@(G1E;7`M)"0B.PHD14Y6>U!!4E]#
M3$5!3GT@/2`Q.PI]"B1S=&UP9&ER("X]("(D<WES>U]D96QI;7TD8V%C:&5?
M9&ER(CL*;6MD:7(@)'-T;7!D:7(L(#`W-34["B1%3E9[4$%27U1%35!](#T@
M)'-T;7!D:7(["FQA<W0["GT*)'!A<E]T96UP(#T@)#$@:68@)$5.5GM005)?
M5$5-4'T@86YD("1%3E9[4$%27U1%35!](#U^("\H+BLI+SL*?0IS=6(@7W-A
M=F5?87,@>PIM>2`H)&YA;64L("1C;VYT96YT<RP@)&UO9&4I(#T@0%\["FUY
M("1F=6QL;F%M92`]("(D<&%R7W1E;7`O)&YA;64B.PIU;FQE<W,@*"UE("1F
M=6QL;F%M92D@>PIM>2`D=&5M<&YA;64@/2`B)&9U;&QN86UE+B0D(CL*;7D@
M)&9H.PHH;W!E;B`D9F@L("<^.G)A=R<L("1T96UP;F%M92D*)B8@*'!R:6YT
M("1F:"`D8V]N=&5N=',I"B8F("AC;&]S92`D9F@I"F]R(&1I92!Q<5M%<G)O
M<B!W<FET:6YG("(D=&5M<&YA;64B.B`D(5T["F-H;6]D("1M;V1E+"`D=&5M
M<&YA;64@:68@9&5F:6YE9"`D;6]D93L*<F5N86UE*"1T96UP;F%M92P@)&9U
M;&QN86UE*2!O<B!U;FQI;FLH)'1E;7!N86UE*3L*?0IR971U<FX@)&9U;&QN
M86UE.PI]"G-U8B!?<V5T7W!R;V=N86UE('L*:68@*&1E9FEN960@)$5.5GM0
M05)?4%)/1TY!345](&%N9"`D14Y6>U!!4E]04D]'3D%-17T@/7X@+R@N*RDO
M*2!["B1P<F]G;F%M92`]("0Q.PI]"B1P<F]G;F%M92!\?#T@)#`["FEF("@D
M14Y6>U!!4E]414U0?2!A;F0@:6YD97@H)'!R;V=N86UE+"`D14Y6>U!!4E]4
M14U0?2D@/CT@,"D@>PHD<')O9VYA;64@/2!S=6)S='(H)'!R;V=N86UE+"!R
M:6YD97@H)'!R;V=N86UE+"`D<WES>U]D96QI;7TI("L@,2D["GT*:68@*"$D
M14Y6>U!!4E]04D]'3D%-17T@;W(@:6YD97@H)'!R;V=N86UE+"`D<WES>U]D
M96QI;7TI(#X](#`I('L*:68@*&]P96X@;7D@)&9H+"`G/"<L("1P<F]G;F%M
M92D@>PIR971U<FX@:68@+7,@)&9H.PI]"FEF("@M<R`B)'!R;V=N86UE)'-Y
M<WM?97AE?2(I('L*)'!R;V=N86UE("X]("1S>7-[7V5X97T["G)E='5R;CL*
M?0I]"F9O<F5A8V@@;7D@)&1I<B`H<W!L:70@+UQ1)'-Y<WMP871H7W-E<'U<
M12\L("1%3E9[4$%42'TI('L*;F5X="!I9B!E>&ES=',@)$5.5GM005)?5$5-
M4'T@86YD("1D:7(@97$@)$5.5GM005)?5$5-4'T["B1D:7(@/7X@<R]<421S
M>7-[7V1E;&EM?5Q%)"\O.PHH*"1P<F]G;F%M92`]("(D9&ER)'-Y<WM?9&5L
M:6U])'!R;V=N86UE)'-Y<WM?97AE?2(I+"!L87-T*0II9B`M<R`B)&1I<B1S
M>7-[7V1E;&EM?21P<F]G;F%M921S>7-[7V5X97TB.PHH*"1P<F]G;F%M92`]
M("(D9&ER)'-Y<WM?9&5L:6U])'!R;V=N86UE(BDL(&QA<W0I"FEF("US("(D
M9&ER)'-Y<WM?9&5L:6U])'!R;V=N86UE(CL*?0I]"G-U8B!?9FEX7W!R;V=N
M86UE('L*)#`@/2`D<')O9VYA;64@?'P]("1%3E9[4$%27U!23T=.04U%?3L*
M:68@*&EN9&5X*"1P<F]G;F%M92P@)'-Y<WM?9&5L:6U]*2`\(#`I('L*)'!R
M;V=N86UE(#T@(BXD<WES>U]D96QI;7TD<')O9VYA;64B.PI]"FUY("1P=V0@
M/2`H9&5F:6YE9"`F0W=D.CIG971C=V0I(#\@0W=D.CIG971C=V0H*0HZ("@H
M9&5F:6YE9"`F5VEN,S(Z.D=E=$-W9"D@/R!7:6XS,CHZ1V5T0W=D*"D@.B!@
M<'=D8"D["F-H;VUP*"1P=V0I.PHD<')O9VYA;64@/7X@<R]>*#\]7"Y<+C]<
M421S>7-[7V1E;&EM?5Q%*2\D<'=D)'-Y<WM?9&5L:6U]+SL*)$5.5GM005)?
M4%)/1TY!345](#T@)'!R;V=N86UE.PI]"G-U8B!?<&%R7VEN:71?96YV('L*
M:68@*"`D14Y6>U!!4E])3DE424%,25I%1'TK*R`]/2`Q("D@>PIR971U<FX[
M"GT@96QS92!["B1%3E9[4$%27TE.251)04Q)6D5$?2`](#(["GT*9F]R("AQ
M=R@@4U!!5TY%1"!414U0($-,14%.($1%0E5'($-!0TA%(%!23T=.04U%("D@
M*2!["F1E;&5T92`D14Y6>R)005)?)%\B?3L*?0IF;W(@*'%W+R!435!$25(@
M5$5-4"!#3$5!3B!$14)51R`O*2!["B1%3E9[(E!!4E\D7R)](#T@)$5.5GLB
M4$%27T=,3T)!3%\D7R)](&EF(&5X:7-T<R`D14Y6>R)005)?1TQ/0D%,7R1?
M(GT["GT*:68@*"1%3E9[4$%27U1%35!]*2!["F1E;&5T92`D14Y6>U!!4E]#
M3$5!3GT["GT*?0IS=6(@;W5T<R!["G)E='5R;B!I9B`D<75I970["FEF("@D
M;&]G9F@I('L*<')I;G0@)&QO9V9H(")`7UQN(CL*?0IE;'-E('L*<')I;G0@
M(D!?7&XB.PI]"GT*<W5B(&EN:71?:6YC('L*<F5Q=6ER92!#;VYF:6<["G!U
M<V@@0$E.0RP@9W)E<"!D969I;F5D+"!M87`@)$-O;F9I9SHZ0V]N9FEG>R1?
M?2P@<7<H"F%R8VAL:6)E>'`@<')I=FQI8F5X<"!S:71E87)C:&5X<"!S:71E
M;&EB97AP"G9E;F1O<F%R8VAE>'`@=F5N9&]R;&EB97AP"BD["GT*<&%C:V%G
M92!M86EN.PIR97%U:7)E(%!!4CL*=6YS:&EF="!`24Y#+"!<)E!!4CHZ9FEN
M9%]P87(["E!!4BT^:6UP;W)T*$!P87)?87)G<RD["F1I92!Q<5MP87(N<&PZ
M($-A;B=T(&]P96X@<&5R;"!S8W)I<'0@(B1P<F]G;F%M92(Z($YO('-U8V@@
M9FEL92!O<B!D:7)E8W1O<GE<;ET*=6YL97-S("UE("1P<F]G;F%M93L*9&\@
M)'!R;V=N86UE.PI#3U)%.CIE>&ET*"0Q*2!I9B`H)$`@/7XO7E]42U]%6$E4
M7UPH*%QD*RE<*2\I.PID:64@)$`@:68@)$`["GT["B0Z.E]?15)23U(@/2`D
M0"!I9B`D0#L*?0I#3U)%.CIE>&ET*"0Q*2!I9B`H)#HZ7U]%4E)/4B`]?B]>
M7U1+7T58251?7"@H7&0K*5PI+RD["F1I92`D.CI?7T524D]2(&EF("0Z.E]?
M15)23U(["C$["E]?14Y$7U\*`%1-4$1)4@``5$5-4$1)4@!414U0`````%1-
M4```````B:O-[P````!P97)L>'-I+F,``````````$-!0TA%```!&P,[[```
M`!P```"8D/__=`8``"22__\$`0``W)+__Q@!``!&I?__4`$``/*E__^\`0``
M3*;__^@!``!4I___0`(``*ZG__]D`@``E*C__Z0"``!.JO__$`,``':J__\D
M`P``/*O__V`#```^J___=`,``!2M___(`P``-JW__^@#```XKO__+`0``)"Q
M__]@!```WK'__X0$```BLO__G`0``$:S___L!```7K/__P@%```XM/__8`4`
M`#ZY__\`!@``[KK__S@&``"6N___J`8``.J[___(!@``QKS__P`'``!XOO__
M.`<````````0``````````-Z4@`!?`$!&PT"`!`````8````&)'__R(`````
M!P$`-````"P```"\D?__:A(```!$#L`%6(@$@0*)!I((DPJ4#`,P$@K!1,A$
MR4321--$U$0.`$(+``!H````9````.ZC__^L`````$(.0$2!`H@$3)804I((
MDPJ4#&:)!I4.9LE"TD+30M1"U4+60L%$R$(.`$(.0($"B`2)!I((DPJ4#)4.
MEA!0R=+3U-761)800M9$D@B3"I0,EA!&TD+30M1"U@`H````T````"ZD__]:
M`````$(.L`%&B`2)!H$"`D8*P4+(0LE"#@!""P```%0```#\````7*3__P@!
M````0@[``423"H$"6(@$1LA0P4+30@X`0@[``8$"B`23"D2)!I((<I0,`EC4
M5`K(0LE"TD(+4I0,2,C)TM1(B`2)!I((E`P````@````5`$```RE__]:````
M`$(.$$*(!$J!`FC(0L%>#@`````\````>`$``$*E___F`````$(.4$25#EH.
MT""(!(D&D@B3"I0,@0(">@H.4$+!0LA"R4+20M-"U$+50@X`0@L`:````+@!
M``#HI?__N@$```!"#G!4B`2)!I((E`R!`I,*EA"7$@+0"L%"R$+)0M)"TT+4
M0M9"UT(.`$(+<)4.F!29%@)8"M5"V$+91`M6U=C91)4.F!29%D;5V-E&E0Z8
M%)D61M5"V$+9````$````"0"```VI___*``````````X````.`(``$JG___&
M`````$(.4$2)!E(.T$"!`H@$D@B3"I0,`I@*#E!"P43(0LE"TD+30M1"#@!"
M"P`0````=`(``-2G__\"`````````%````"(`@``PJ?__]8!````1@[P`68.
M\"&(!(D&D@B8%($"DPJ4#)4.EA"7$ID6FA@"8@H.\`%"P4+(0LE"TD+30M1"
MU4+60M="V$+90MI"#@!""QP```#<`@``1*G__R(`````0@X02(@$@0)0R$+!
M0@X`0````/P"``!&J?__`@$```!"#C!2#K`@D@B!`H@$B08"J`H.,$+!0LA"
MR4+20@X`0@M6"@XP0L%"R$+)0M)*#@!$"P`P````0`,```2J__]8`P```$(.
M0$J(!(D&D@B3"H$"`PH#"LA"P4+)0M)"TU(.`$0+````(````'0#```HK?__
M3@````!"#B!$B`2!`GH*P4+(0@X`0@L`%````)@#``!2K?__1`````!"#F!"
M@1(`3````+`#``!^K?__)`$```!"#G!$B`1<#O"`!),*E`R9%H$"B0:2")4.
MEA"7$I@4`L(*#G!"P4+(0LE"TD+30M1"U4+60M="V$+90@X`0@L8``````0`
M`%*N__\8`````$(.$$*!`E#!0@X`5````!P$``!.KO__V@````!"#D!&B0:2
M"($":(@$6@K(0L%"R4+20@X`0@M"R%C!0LE"TD(.`$0.0($"B`2)!I((1`J3
M"@)$TT+(2@M"DPI$R--$B`23"IP```!T!```T*[__P8%````2@[P`EJ)!I((
MDPJ!`H@$`G"4#)4.EA"7$I@4`R0!F18"/-E2"L%"R$+50M9"UT+80LE"TD+3
M1-1"#@!""P)>F18#4`'98M35UM?85LA"P4+)0M)"TT(.`$0.\`*!`H@$B0:2
M"),*E`R5#I80EQ*8%)D6`]X`V4*9%D34U=;7V-E,E`R5#I80EQ*8%)D6```T
M````%`4``#:S__^P`0```$(.0$*(!%*2"),*@0*)!I0,`T8!"L%"R$+)0M)"
MTT+40@X`0@L``#@```!,!0``KK3__Z@`````0@XP2(@$B0:2"($"`F(*P4+(
M0LE"TD(.`$(+8`K(0L%"TD3)0@X`1`L``#````"(!0``'(K__XH!````0@Y@
M3($"B0:(!)((DPH##@$*P4+(0LE"TT320@X`0@L````<````O`4``.:T__]4
M`````$(.$$:!`@)(P4(.`````#0```#<!0``&K7__]P`````0@Y`3H@$B0:2
M")4.@0*3"I0,`G8*P4+(0LE"TD+30M1"U4(.`$(+-````!0&``"^M?__L@$`
M``!"#C!,B`2)!I0,@0*2"),*`TP!"LA"P4+)0M)"TT+40@X`1`L````0````
M3`8``#BW__\,````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````!```````````#
M`````````0`````````+`P````````$`````````%0,````````=````````
M`+\$````````(`````````"XK0```````"$`````````"``````````9````
M`````,"M````````&P`````````(`````````!H`````````R*T````````<
M``````````@`````````!`````````#8`@```````/7^_V\```````8`````
M```%`````````(`0````````!@````````#P!@````````H`````````]00`
M```````+`````````!@`````````%0````````````````````,`````````
M4+`````````"`````````'`%````````%``````````'`````````!<`````
M````N!@````````'`````````*@6````````"`````````"`!P````````D`
M````````&``````````>``````````@`````````^___;P`````!```(````
M`/[__V\`````2!8```````#___]O``````(`````````\/__;P````!V%0``
M`````/G__V\`````"P``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````"E!!4BYP;0H`````````````````````````
M````````````````````````````````````````````````````````````
M__________\``````````#`>````````,!X````````P'@```````#`>````
M````,!X````````P'@```````#`>````````,!X````````P'@```````#`>
M````````,!X````````P'@```````#`>````````,!X````````P'@``````
M`#`>````````,!X````````P'@```````#`>````````,!X````````P'@``
M`````#`>````````,!X````````P'@```````#`>````````,!X````````P
M'@```````#`>````````,!X````````P'@```````#`>````````,!X`````
M```P'@```````#`>````````,!X````````P'@```````#`>````````,!X`
M```````P'@```````#`>````````,!X````````P'@```````#`>````````
M,!X````````P'@```````#`>````````,!X````````P'@```````#`>````
M````,!X````````P'@```````#`>````````,!X````````P'@```````#`>
M````````,!X````````P'@```````#`>````````T*T`````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!'
M0T,Z("A355-%($QI;G5X*2`Q,RXQ+C$@,C`R,S`W,C`@6W)E=FES:6]N(#EA
M86,S-V%B.&$W8CDQ.6$X.6,V9#8T8F,W,3`W83@T,S8Y.39E.3-=`$%2````
M<FES8W8``4@````$$`5R=C8T:3)P,5]M,G`P7V$R<#%?9C)P,E]D,G`R7V,R
M<#!?>FEC<W(R<#!?>FEF96YC96DR<#!?>FUM=6PQ<#```"YS:'-T<G1A8@`N
M:6YT97)P`"YN;W1E+F=N=2YB=6EL9"UI9``N;F]T92Y!0DDM=&%G`"YG;G4N
M:&%S:``N9'EN<WEM`"YD>6YS='(`+F=N=2YV97)S:6]N`"YG;G4N=F5R<VEO
M;E]R`"YR96QA+F1Y;@`N<F5L82YP;'0`+G1E>'0`+G)O9&%T80`N96A?9G)A
M;65?:&1R`"YE:%]F<F%M90`N<')E:6YI=%]A<G)A>0`N:6YI=%]A<G)A>0`N
M9FEN:5]A<G)A>0`N9'EN86UI8P`N9&%T80`N9V]T`"YB<W,`+F-O;6UE;G0`
M+G)I<V-V+F%T=')I8G5T97,`````````````````````````````````````
M``````````````````````````````````````````````````L````!````
M`@````````!P`@```````'`"````````(0````````````````````$`````
M```````````````3````!P````(`````````E`(```````"4`@```````"0`
M```````````````````$````````````````````)@````<````"````````
M`+@"````````N`(````````@````````````````````!```````````````
M`````#@````%`````@````````#8`@```````-@"````````)`,````````&
M``````````@`````````!``````````T````]O__;P(```````````8`````
M````!@```````.P`````````!@`````````(````````````````````/@``
M``L````"`````````/`&````````\`8```````"0"0````````<````"````
M"``````````8`````````$8````#`````@````````"`$````````(`0````
M````]00```````````````````$```````````````````!.````____;P(`
M````````=A4```````!V%0```````,P`````````!@`````````"````````
M``(`````````6P```/[__V\"`````````$@6````````2!8```````!@````
M``````<````"````"````````````````````&H````$`````@````````"H
M%@```````*@6````````$`(````````&``````````@`````````&```````
M``!T````!````$(`````````N!@```````"X&````````'`%````````!@``
M`!8````(`````````!@`````````>0````$````&`````````#`>````````
M,!X```````#``P``````````````````$``````````0`````````'X````!
M````!@````````#P(0```````/`A````````["T```````````````````0`
M``````````````````"$`````0````(`````````X$\```````#@3P``````
M`'=!```````````````````(````````````````````C`````$````"````
M`````%B1````````6)$```````#L````````````````````!```````````
M`````````)H````!`````@````````!(D@```````$B2````````8`8`````
M``````````````@```````````````````"D````$`````,`````````N*T`
M``````"XG0````````@````````````````````!``````````@`````````
MLP````X````#`````````,"M````````P)T````````(````````````````
M````"``````````(`````````+\````/`````P````````#(K0```````,B=
M````````"`````````````````````@`````````"`````````#+````!@``
M``,`````````T*T```````#0G0```````#`"````````!P`````````(````
M`````!``````````U`````$````#``````````"P`````````*````````!0
M````````````````````"````````````````````-H````!`````P``````
M``!0L````````%"@````````2`(```````````````````@`````````"```
M``````#?````"`````,`````````F+(```````"8H@```````"@`````````
M```````````(````````````````````Y`````$````P````````````````
M````F*(```````!6`````````````````````0`````````!`````````.T`
M```#``!P`````````````````````.ZB````````4P``````````````````
M``$````````````````````!`````P````````````````````````!!HP``
D`````/\````````````````````!````````````````````
